@@ -1,29 +1,21 @@
 """A Python package for the analysis of biopsychological data."""
-import platform
 
-import matplotlib
-import neurokit2
-import numpy as np
-import pandas as pd
-import pingouin
-import scipy
-
-import biopsykit.carwatch_logs  # pylint: disable=unused-import
-import biopsykit.classification  # pylint: disable=unused-import
-import biopsykit.example_data  # pylint: disable=unused-import
-import biopsykit.io  # pylint: disable=unused-import
-import biopsykit.metadata  # pylint: disable=unused-import
-import biopsykit.plotting  # pylint: disable=unused-import
-import biopsykit.protocols  # pylint: disable=unused-import
-import biopsykit.questionnaires  # pylint: disable=unused-import
-import biopsykit.saliva  # pylint: disable=unused-import
-import biopsykit.signals  # pylint: disable=unused-import
-import biopsykit.sleep  # pylint: disable=unused-import
-import biopsykit.stats  # pylint: disable=unused-import
-import biopsykit.utils  # pylint: disable=unused-import
+from biopsykit import (
+    classification,
+    example_data,
+    io,
+    metadata,
+    plotting,
+    protocols,
+    questionnaires,
+    saliva,
+    signals,
+    sleep,
+    stats,
+    utils,
+)
 
 __all__ = [
-    "carwatch_logs",
     "classification",
     "example_data",
     "io",
@@ -38,7 +30,7 @@ __all__ = [
     "utils",
 ]
 
-__version__ = "0.8.1"
+__version__ = "0.13.0"
 
 
 def version() -> None:
@@ -51,6 +43,15 @@ def version() -> None:
     >>> bp.version()
 
     """
+    import platform
+
+    import matplotlib
+    import neurokit2
+    import numpy as np
+    import pandas as pd
+    import pingouin
+    import scipy
+
     print(
         f"Operating System: {platform.system()} ({platform.architecture()[1]} {platform.architecture()[0]})\n",
         f"- Python: {platform.python_version()}\n",
