@@ -1,4 +1,5 @@
 """Module for the classification of (biopsychological) data."""
+
 from biopsykit.classification import analysis, model_selection, utils
 
-__all__ = ["utils", "model_selection", "analysis"]
+__all__ = ["analysis", "model_selection", "utils"]
