@@ -1,6 +1,7 @@
 """Module with functions for model selection using "nested" cross-validation."""
+
 import warnings
-from typing import Any, Dict, Optional
+from typing import Any, Optional
 
 import numpy as np
 from sklearn.metrics import confusion_matrix, get_scorer
@@ -14,14 +15,14 @@ __all__ = ["nested_cv_param_search"]
 
 
 def nested_cv_param_search(  # pylint:disable=invalid-name # pylint:disable=too-many-branches
-    X: np.ndarray,  # pylint:disable=invalid-name
+    X: np.ndarray,  # pylint:disable=invalid-name  # noqa: N803
     y: np.ndarray,
-    param_dict: Dict[str, Any],
+    param_dict: dict[str, Any],
     pipeline: Pipeline,
     outer_cv: BaseCrossValidator,
     inner_cv: BaseCrossValidator,
     groups: Optional[np.ndarray] = None,
-    hyper_search_params: Optional[Dict[str, Any]] = None,
+    hyper_search_params: Optional[dict[str, Any]] = None,
     **kwargs,
 ):
     """Perform a cross-validated parameter search with hyperparameter optimization within a outer cross-validation.
@@ -135,9 +136,7 @@ def nested_cv_param_search(  # pylint:disable=invalid-name # pylint:disable=too-
 
         results_dict["param_search"].append(cv_obj)
         for scorer in scoring_dict:
-            results_dict["test_{}".format(scorer)].append(
-                get_scorer(scorer)._score_func(y_test, cv_obj.predict(x_test))
-            )
+            results_dict[f"test_{scorer}"].append(get_scorer(scorer)._score_func(y_test, cv_obj.predict(x_test)))
         results_dict["train_indices"].append(train)
         results_dict["test_indices"].append(test)
         results_dict["predicted_labels"].append(cv_obj.predict(x_test))
@@ -148,6 +147,7 @@ def nested_cv_param_search(  # pylint:disable=invalid-name # pylint:disable=too-
             results_dict["conf_matrix"].append(confusion_matrix(y_test, cv_obj.predict(x_test), normalize=None))
         except ValueError as e:
             if "Classification metrics can't handle a mix of multiclass and continuous targets" in e.args[0]:
+                # TODO: add "error_handling" parameter to allow for different error handling strategies
                 warnings.warn("Cannot compute confusion matrix for regression tasks.")
 
     return results_dict
@@ -181,16 +181,16 @@ def _fit_cv_obj_one_fold(cv_obj, x_train, y_train, groups_train):
             ) from e
         if "An empty dict was passed." in e.args[0]:
             raise ValueError("No scoring metric was specified for the estimator!") from e
-        raise e
+        raise ValueError from e
     return cv_obj
 
 
 def _get_param_search_cv_object(
     pipeline: Pipeline,
-    param_dict: Dict[str, Any],
+    param_dict: dict[str, Any],
     inner_cv: BaseCrossValidator,
-    scoring_dict: Dict[str, str],
-    hyper_search_config: Dict[str, Any],
+    scoring_dict: dict[str, str],
+    hyper_search_config: dict[str, Any],
     **kwargs,
 ):
     random_state = kwargs.pop("random_state", None)
