@@ -1,6 +1,7 @@
 """Module with utility functions for machine learning and classification applications."""
+
 from copy import deepcopy
-from typing import Dict, Optional, Tuple, Union
+from typing import Optional, Union
 
 import numpy as np
 import pandas as pd
@@ -72,7 +73,7 @@ def strip_labels(data: Union[pd.DataFrame, pd.Series], label_col: Optional[str]
 
 def factorize_subject_id(
     data: Union[pd.Series, pd.DataFrame], subject_col: Optional[str] = None
-) -> Tuple[np.ndarray, np.ndarray]:
+) -> tuple[np.ndarray, np.ndarray]:
     """Factorize subject IDs, i.e., encode them as an enumerated type or categorical variable.
 
     Parameters
@@ -105,7 +106,7 @@ def prepare_df_sklearn(
     label_col: Optional[str] = None,
     subject_col: Optional[str] = None,
     print_summary: Optional[bool] = False,
-) -> Tuple[np.ndarray, ...]:
+) -> tuple[np.ndarray, ...]:
     """Prepare a dataframe for usage in sklearn functions and return the single components of the dataframe.
 
     This function performs the following steps:
@@ -150,21 +151,20 @@ def prepare_df_sklearn(
 
     if print_summary:
         print(
-            "Shape of X: {}; shape of y: {}; number of groups: {}, class prevalence: {}".format(
-                x_data.shape, y_data.shape, len(group_keys), np.unique(y_data, return_counts=True)[1]
-            )
+            f"Shape of X: {x_data.shape}; shape of y: {y_data.shape}; "
+            f"number of groups: {len(group_keys)}, class prevalence: {np.unique(y_data, return_counts=True)[1]}"
         )
 
     return x_data, y_data, groups, group_keys
 
 
-def split_train_test(  # pylint:disable=invalid-name
-    X: np.ndarray,  # noqa
+def split_train_test(
+    X: np.ndarray,  # noqa: N803
     y: np.ndarray,
     train: np.ndarray,
     test: np.ndarray,
     groups: Optional[np.ndarray] = None,
-) -> Tuple[np.ndarray, ...]:
+) -> tuple[np.ndarray, ...]:
     """Split data into train and test set.
 
     Parameters
@@ -199,7 +199,7 @@ def split_train_test(  # pylint:disable=invalid-name
         Group labels of test data (only available if ``groups`` is not ``None``)
 
     """
-    X_train, X_test = X[train], X[test]  # noqa
+    X_train, X_test = X[train], X[test]  # noqa: N806
     y_train, y_test = y[train], y[test]
 
     if groups is None:
@@ -210,7 +210,7 @@ def split_train_test(  # pylint:disable=invalid-name
     return X_train, X_test, y_train, y_test, groups_train, groups_test
 
 
-def merge_nested_dicts(dict1: Dict, dict2: Dict) -> Dict:
+def merge_nested_dicts(dict1: dict, dict2: dict) -> dict:
     """Merge two nested dictionaries.
 
     Parameters
@@ -230,14 +230,24 @@ def merge_nested_dicts(dict1: Dict, dict2: Dict) -> Dict:
     return _merge_nested_dicts(dict1, dict2)
 
 
-def _merge_nested_dicts(dict1: Dict, dict2: Dict) -> Dict:
+def _merge_nested_dicts(dict1: dict, dict2: dict) -> dict:
     for key, value in dict2.items():
         if isinstance(value, dict) and key in dict1:
             _merge_nested_dicts(dict1[key], value)
             # check if value is list
         elif isinstance(value, list) and key in dict1:
             dict1[key] = value if key not in dict1 else dict1[key] + value
-        else:
-            if key not in dict1:
-                dict1[key] = value
+            list_of_dicts = deepcopy(dict1[key])
+            merged_dict = {}
+
+            for d in list_of_dicts:
+                for k, v in d.items():
+                    # Use set to avoid duplicates, then convert it back to a list
+                    merged_dict[k] = list(set(merged_dict.get(k, []) + list(v)))
+
+            # Convert the merged result back to dictionaries
+            result = [dict(merged_dict)]
+            dict1[key] = result
+        elif key not in dict1:
+            dict1[key] = value
     return dict1
