@@ -3,8 +3,10 @@
 The data is either taken from the local file system in case biopsykit was installed manually or the example data is
 downloaded into the local user folder.
 """
+
+from collections.abc import Sequence
 from pathlib import Path
-from typing import Dict, Optional, Sequence, Tuple, Union
+from typing import Optional, Union
 from urllib.request import urlretrieve
 
 import pandas as pd
@@ -17,7 +19,6 @@ from biopsykit.io import (
     load_subject_condition_list,
     load_time_log,
 )
-from biopsykit.io.carwatch_logs import load_log_one_subject
 from biopsykit.io.ecg import load_hr_phase_dict
 from biopsykit.io.eeg import MuseDataset
 from biopsykit.io.nilspod import load_dataset_nilspod
@@ -28,8 +29,8 @@ from biopsykit.io.sleep_analyzer import (
     load_withings_sleep_analyzer_raw_folder,
     load_withings_sleep_analyzer_summary,
 )
-from biopsykit.utils._types import path_t
-from biopsykit.utils.datatype_helper import (
+from biopsykit.utils._types_internal import path_t
+from biopsykit.utils.dtypes import (
     HeartRatePhaseDict,
     HeartRateSubjectDataDict,
     SalivaMeanSeDataFrame,
@@ -47,32 +48,28 @@ _REMOTE_DATA_PATH = "https://raw.githubusercontent.com/mad-lab-fau/BioPsyKit/mai
 
 __all__ = [
     "get_condition_list_example",
-    "get_saliva_example_plate_format",
-    "get_saliva_example",
-    "get_saliva_mean_se_example",
-    "get_mist_hr_example",
-    "get_hr_result_sample",
-    "get_hr_ensemble_sample",
-    "get_hr_subject_data_dict_example",
-    "get_hr_subject_data_dict_tuple_example",
-    "get_ecg_processing_results_path_example",
-    "get_ecg_path_example",
     "get_ecg_example",
     "get_ecg_example_02",
+    "get_ecg_path_example",
+    "get_ecg_processing_results_path_example",
     "get_eeg_example",
-    "get_sleep_analyzer_raw_file_unformatted",
-    "get_sleep_analyzer_raw_file",
-    "get_sleep_analyzer_raw_example",
-    "get_sleep_analyzer_summary_example",
-    "get_sleep_imu_example",
-    "get_car_watch_log_path_example",
-    "get_car_watch_log_data_zip_path_example",
-    "get_car_watch_log_path_all_subjects_example",
-    "get_car_watch_log_data_example",
-    "get_time_log_example",
+    "get_hr_ensemble_sample",
+    "get_hr_result_sample",
+    "get_hr_subject_data_dict_example",
+    "get_hr_subject_data_dict_tuple_example",
+    "get_mist_hr_example",
     "get_questionnaire_example",
     "get_questionnaire_example_wrong_range",
+    "get_saliva_example",
+    "get_saliva_example_plate_format",
+    "get_saliva_mean_se_example",
+    "get_sleep_analyzer_raw_example",
+    "get_sleep_analyzer_raw_file",
+    "get_sleep_analyzer_raw_file_unformatted",
+    "get_sleep_analyzer_summary_example",
+    "get_sleep_imu_example",
     "get_stats_example",
+    "get_time_log_example",
 ]
 
 # TODO add SHA256 check to assert whether remote example data was changed and should be re-downloaded.
@@ -141,7 +138,7 @@ def get_condition_list_example() -> SubjectConditionDataFrame:
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SubjectConditionDataFrame`
+    :obj:`~biopsykit.utils.dtypes.SubjectConditionDataFrame`
         dataframe with example subject condition assignment
 
     """
@@ -156,7 +153,7 @@ def get_saliva_example_plate_format(
     id_col_names: Optional[Sequence[str]] = None,
     regex_str: Optional[str] = None,
     sample_times: Optional[Sequence[int]] = None,
-    condition_list: Optional[Union[Sequence, Dict[str, Sequence], pd.Index]] = None,
+    condition_list: Optional[Union[Sequence, dict[str, Sequence], pd.Index]] = None,
 ) -> pd.DataFrame:
     r"""Return example saliva data from "plate" format.
 
@@ -179,7 +176,7 @@ def get_saliva_example_plate_format(
 
     Returns
     -------
-    data : :class:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+    data : :class:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
         saliva data in `SalivaRawDataFrame` format
 
     See Also
@@ -210,7 +207,7 @@ def get_saliva_example(sample_times: Optional[Sequence[int]] = None) -> SalivaRa
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+    :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
         dataframe with example raw saliva data
 
     """
@@ -222,13 +219,13 @@ def get_saliva_example(sample_times: Optional[Sequence[int]] = None) -> SalivaRa
     )
 
 
-def get_saliva_mean_se_example() -> Dict[str, SalivaMeanSeDataFrame]:
+def get_saliva_mean_se_example() -> dict[str, SalivaMeanSeDataFrame]:
     """Return dictionary with mean and standard error from example data for different saliva types.
 
     Returns
     -------
     dict
-        dictionary with :obj:`~biopsykit.utils.datatype_helper.SalivaMeanSeDataFrame` from different saliva types
+        dictionary with :obj:`~biopsykit.utils.dtypes.SalivaMeanSeDataFrame` from different saliva types
 
     """
     data_dict = pd.read_excel(_get_data("saliva_sample_mean_se.xlsx"), sheet_name=None)
@@ -239,11 +236,11 @@ def get_saliva_mean_se_example() -> Dict[str, SalivaMeanSeDataFrame]:
 
 
 def get_hr_subject_data_dict_example() -> HeartRateSubjectDataDict:
-    """Return heart rate example data in the form of a :obj:`~biopsykit.utils.datatype_helper.HeartRateSubjectDataDict`.
+    """Return heart rate example data in the form of a :obj:`~biopsykit.utils.dtypes.HeartRateSubjectDataDict`.
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.HeartRateSubjectDataDict`
+    :obj:`~biopsykit.utils.dtypes.HeartRateSubjectDataDict`
         dictionary with heart rate time-series data from multiple subjects, each containing data from different phases.
 
     """
@@ -256,12 +253,11 @@ def get_hr_subject_data_dict_example() -> HeartRateSubjectDataDict:
 
 
 def get_hr_subject_data_dict_tuple_example() -> HeartRateSubjectDataDict:
-    """Return heart rate example data in the form of a \
-    :obj:`~biopsykit.utils.datatype_helper.HeartRateSubjectDataDict`, but with tuples as keys instead of strings.
+    """Return HR example data as a ``HeartRateSubjectDataDict``, but with tuples as keys instead of strings.
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.HeartRateSubjectDataDict`
+    :obj:`~biopsykit.utils.dtypes.HeartRateSubjectDataDict`
         dictionary with heart rate time-series, each containing data from different phases.
 
     """
@@ -289,7 +285,7 @@ def get_hr_result_sample() -> pd.DataFrame:
     return load_long_format_csv(_get_data("hr_result_sample.csv"))
 
 
-def get_hr_ensemble_sample() -> Dict[str, pd.DataFrame]:
+def get_hr_ensemble_sample() -> dict[str, pd.DataFrame]:
     """Return heart rate ensemble example data.
 
     The example data consists of time-series heart rate of multiple subjects for different study phases,
@@ -309,7 +305,7 @@ def get_mist_hr_example() -> HeartRatePhaseDict:
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`
+    :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`
         dictionary with heart rate time-series data from one subject during multiple phases
 
     """
@@ -351,7 +347,7 @@ def get_ecg_processing_results_path_example() -> path_t:
     return file_path.parent
 
 
-def get_ecg_example() -> Tuple[pd.DataFrame, float]:
+def get_ecg_example() -> tuple[pd.DataFrame, float]:
     """Return raw ECG example data from one subject.
 
     Returns
@@ -365,7 +361,7 @@ def get_ecg_example() -> Tuple[pd.DataFrame, float]:
     return load_dataset_nilspod(file_path=_get_data("ecg/ecg_sample_Vp01.bin"), datastreams=["ecg"])
 
 
-def get_ecg_example_02() -> Tuple[pd.DataFrame, float]:
+def get_ecg_example_02() -> tuple[pd.DataFrame, float]:
     """Return second raw ECG example data from another subject.
 
     Returns
@@ -396,9 +392,7 @@ def get_sleep_analyzer_raw_file_unformatted(data_source: str) -> pd.DataFrame:
     """
     if data_source not in WITHINGS_RAW_DATA_SOURCES.values():
         raise ValueError(
-            "Unsupported data source {}! Must be one of {}.".format(
-                data_source, list(WITHINGS_RAW_DATA_SOURCES.values())
-            )
+            f"Unsupported data source {data_source}! Must be one of {list(WITHINGS_RAW_DATA_SOURCES.values())}."
         )
     ds_name = list(WITHINGS_RAW_DATA_SOURCES.keys())[list(WITHINGS_RAW_DATA_SOURCES.values()).index(data_source)]
     return pd.read_csv(_get_data(f"sleep/raw_sleep-monitor_{ds_name}.csv"))
@@ -407,7 +401,7 @@ def get_sleep_analyzer_raw_file_unformatted(data_source: str) -> pd.DataFrame:
 def get_sleep_analyzer_raw_file(
     data_source: str,
     split_into_nights: Optional[bool] = True,
-) -> Union[pd.DataFrame, Dict[str, pd.DataFrame]]:
+) -> Union[pd.DataFrame, dict[str, pd.DataFrame]]:
     """Return Withings Sleep Analyzer raw data example file.
 
     Parameters
@@ -428,9 +422,7 @@ def get_sleep_analyzer_raw_file(
     """
     if data_source not in WITHINGS_RAW_DATA_SOURCES.values():
         raise ValueError(
-            "Unsupported data source {}! Must be one of {}.".format(
-                data_source, list(WITHINGS_RAW_DATA_SOURCES.values())
-            )
+            f"Unsupported data source {data_source}! Must be one of {list(WITHINGS_RAW_DATA_SOURCES.values())}."
         )
 
     ds_name = list(WITHINGS_RAW_DATA_SOURCES.keys())[list(WITHINGS_RAW_DATA_SOURCES.values()).index(data_source)]
@@ -443,7 +435,7 @@ def get_sleep_analyzer_raw_file(
 
 def get_sleep_analyzer_raw_example(
     split_into_nights: Optional[bool] = True,
-) -> Union[pd.DataFrame, Dict[str, pd.DataFrame]]:
+) -> Union[pd.DataFrame, dict[str, pd.DataFrame]]:
     """Return Withings Sleep Analyzer example raw data.
 
     Parameters
@@ -479,14 +471,14 @@ def get_sleep_analyzer_summary_example() -> SleepEndpointDataFrame:
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SleepEndpointDataFrame`
+    :obj:`~biopsykit.utils.dtypes.SleepEndpointDataFrame`
         dataframe with example sleep endpoints computed from Withings Sleep Analyzer Summary data
 
     """
     return load_withings_sleep_analyzer_summary(_get_data("sleep/sleep.csv"))
 
 
-def get_sleep_imu_example() -> Tuple[pd.DataFrame, float]:
+def get_sleep_imu_example() -> tuple[pd.DataFrame, float]:
     """Return raw IMU example data collected from a wrist-worn IMU sensor during night.
 
     Returns
@@ -514,92 +506,6 @@ def get_eeg_example() -> MuseDataset:
     return MuseDataset.from_csv_file(_get_data("eeg_muse_example.csv"), tz="Europe/Berlin")
 
 
-def get_car_watch_log_path_example() -> path_t:
-    """Return folder path to *CARWatch App* log files from *one* subject.
-
-    Returns
-    -------
-    :class:`~pathlib.Path` or str
-        path to folder with *CARWatch App* log files.
-
-    """
-    # ensure that folder exists and data in folder is available
-    file_list = [
-        "carwatch_de34f_20191205.csv",
-        "carwatch_de34f_20191206.csv",
-        "carwatch_de34f_20191207.csv",
-        "carwatch_de34f_20191208.csv",
-    ]
-    file_path = None
-    for file in file_list:
-        file_path = _get_data(f"log_data/DE34F/{file}")
-    # get parent directory
-    return file_path.parent
-
-
-def get_car_watch_log_data_zip_path_example() -> path_t:
-    """Return path to *CARWatch App* example log data as zip file from *one* subject.
-
-    Returns
-    -------
-    :class:`~pathlib.Path` or str
-        path to *CARWatch App* example log data as zip file
-
-    """
-    return _get_data("log_data/logs_AB12C.zip")
-
-
-def get_car_watch_log_data_example() -> pd.DataFrame:
-    """Return *CARWatch App* example log data from folder from *one* subject.
-
-    Returns
-    -------
-    data : :class:`~pandas.DataFrame`
-        dataframe with example log data from the *CARWatch* app
-
-    """
-    # ensure that all files are available
-    file_list = [
-        "carwatch_de34f_20191205.csv",
-        "carwatch_de34f_20191206.csv",
-        "carwatch_de34f_20191207.csv",
-        "carwatch_de34f_20191208.csv",
-    ]
-    file_path = None
-    for file in file_list:
-        file_path = _get_data(f"log_data/DE34F/{file}")
-    # get parent directory
-    file_path = file_path.parent
-    return load_log_one_subject(file_path)
-
-
-def get_car_watch_log_path_all_subjects_example() -> path_t:
-    """Return folder path to *CARWatch App* log files for *multiple* subjects.
-
-    Returns
-    -------
-    :class:`~pathlib.Path` or str
-        path to folder with *CARWatch App* log files.
-
-    """
-    # ensure that folder exists and data in folder is available
-    file_list = [
-        "DE34F/carwatch_de34f_20191205.csv",
-        "DE34F/carwatch_de34f_20191206.csv",
-        "DE34F/carwatch_de34f_20191207.csv",
-        "DE34F/carwatch_de34f_20191208.csv",
-        "GH56I/carwatch_gh56i_20191205.csv",
-        "GH56I/carwatch_gh56i_20191206.csv",
-        "GH56I/carwatch_gh56i_20191207.csv",
-        "GH56I/carwatch_gh56i_20191208.csv",
-    ]
-    file_path = None
-    for file in file_list:
-        file_path = _get_data(f"log_data/{file}")
-    # get parent directory
-    return file_path.parent.parent
-
-
 def get_time_log_example() -> pd.DataFrame:
     """Return time log example data.
 
