@@ -1,7 +1,8 @@
 """Module for importing data recorded by the Biopac system."""
 
 import datetime
-from typing import Dict, Optional, Sequence, Tuple, Union
+from collections.abc import Sequence
+from typing import ClassVar, Optional, Union
 
 try:
     import bioread
@@ -14,7 +15,7 @@ except ImportError as e:
 import pandas as pd
 
 from biopsykit.utils._datatype_validation_helper import _assert_file_extension
-from biopsykit.utils._types import path_t, str_t
+from biopsykit.utils._types_internal import path_t, str_t
 
 __all__ = ["BiopacDataset"]
 
@@ -22,7 +23,7 @@ __all__ = ["BiopacDataset"]
 class BiopacDataset:
     """Class for loading and processing Biopac data."""
 
-    _CHANNEL_NAME_MAPPING = {
+    _CHANNEL_NAME_MAPPING: ClassVar[dict[str, str]] = {
         "ECG": "ecg",
         "RSP": "rsp",
         "EDA": "eda",
@@ -35,13 +36,13 @@ class BiopacDataset:
     _start_time_unix: pd.Timestamp
     _tz: str
     _event_markers: Optional[Sequence[bioread.reader.EventMarker]] = None
-    _data: Dict[str, pd.DataFrame] = {}
-    _sampling_rate: Dict[str, int] = {}
+    _data: ClassVar[dict[str, pd.DataFrame]] = {}
+    _sampling_rate: ClassVar[dict[str, int]] = {}
 
     def __init__(
         self,
-        data_dict: Dict[str, pd.DataFrame],
-        sampling_rate_dict: Dict[str, int],
+        data_dict: dict[str, pd.DataFrame],
+        sampling_rate_dict: dict[str, int],
         start_time: Optional[pd.Timestamp] = None,
         event_markers: Optional[Sequence[bioread.reader.EventMarker]] = None,
         tz: Optional[str] = None,
@@ -80,13 +81,17 @@ class BiopacDataset:
         self._tz = tz
 
     @classmethod
-    def from_acq_file(cls, path: path_t, tz: Optional[str] = "Europe/Berlin"):
+    def from_acq_file(
+        cls, path: path_t, channel_mapping: Optional[dict[str, str]] = None, tz: Optional[str] = "Europe/Berlin"
+    ):
         """Create a new Dataset from a valid .acq file.
 
         Parameters
         ----------
         path : :class:`pathlib.Path` or str
             Path to the file
+        channel_mapping : dict, optional
+            Dictionary containing the mapping of the channel names in the .acq to the channel names used in the Dataset.
         tz : str, optional
             Timezone str of the recording. This can be used to localize the start and end time.
             Note, this should not be the timezone of your current PC, but the timezone relevant for the specific
@@ -105,7 +110,10 @@ class BiopacDataset:
             # start time is the marker time minus the time at the position of the marker sample
             start_time = marker_time - pd.Timedelta(seconds=biopac_data.time_index[marker_sample_idx])
 
-        dict_channel_data, dict_sampling_rate = cls._extract_channel_information(biopac_data)
+        if channel_mapping is None:
+            channel_mapping = cls._CHANNEL_NAME_MAPPING
+
+        dict_channel_data, dict_sampling_rate = cls._extract_channel_information(biopac_data, channel_mapping)
 
         return cls(
             data_dict=dict_channel_data,
@@ -158,7 +166,7 @@ class BiopacDataset:
         datastreams = self._sanitize_datastreams_input(datastreams)
 
         # assert that all datastreams have the same sampling rate
-        sampling_rates = set(self._sampling_rate[datastream] for datastream in datastreams)
+        sampling_rates = {self._sampling_rate[datastream] for datastream in datastreams}
         if len(sampling_rates) > 1:
             raise ValueError("All datastreams must have the same sampling rate for combining it into one DataFrame!")
 
@@ -171,13 +179,15 @@ class BiopacDataset:
 
     @classmethod
     def _extract_channel_information(
-        cls, biopac_data: bioread.reader.Datafile
-    ) -> Tuple[Dict[str, pd.DataFrame], Dict[str, int]]:
+        cls, biopac_data: bioread.reader.Datafile, channel_mapping: dict[str, str]
+    ) -> tuple[dict[str, pd.DataFrame], dict[str, int]]:
+        # TODO raise warning or error when there are more channels than were extracted
+        #  (might be an indication that mapping does not contain all channels)
         dict_channel_data = {}
         dict_sampling_rate = {}
         for channel in biopac_data.channels:
             # check if channel name is in mapping
-            for key, value in cls._CHANNEL_NAME_MAPPING.items():
+            for key, value in channel_mapping.items():
                 if channel.name.startswith(key):
                     ch_name = value
                     channel_df = pd.DataFrame(
@@ -214,10 +224,6 @@ class BiopacDataset:
             data = data.reset_index(drop=True)
             data.index.name = index_name
             return data
-        if index == "utc":
-            # convert counter to utc timestamps
-            data.index += self.start_time_unix.timestamp()
-            return data
 
         if start_time is None:
             start_time = self.start_time_unix
@@ -228,9 +234,14 @@ class BiopacDataset:
                 "Use a different index representation or provide a custom start time using the 'start_time' parameter."
             )
 
+        if index == "utc":
+            # convert counter to utc timestamps
+            data.index += start_time.timestamp()
+            return data
+
         # convert counter to pandas datetime index
         data.index = pd.to_timedelta(data.index, unit="s")
-        data.index += self.start_time_unix
+        data.index += start_time
 
         if index == "local_datetime":
             data.index = data.index.tz_convert(self.timezone)
