@@ -1,21 +1,23 @@
 """I/O functions for files related to ECG processing."""
+
 import re
 import warnings
+from collections.abc import Sequence
 from pathlib import Path
-from typing import Optional, Sequence
+from typing import Optional
 
 import pandas as pd
 
 from biopsykit.utils._datatype_validation_helper import _assert_file_extension, _assert_is_dir
-from biopsykit.utils._types import path_t
-from biopsykit.utils.datatype_helper import HeartRatePhaseDict, HeartRateSubjectDataDict, is_hr_phase_dict
+from biopsykit.utils._types_internal import path_t
+from biopsykit.utils.dtypes import HeartRatePhaseDict, HeartRateSubjectDataDict, is_hr_phase_dict
 from biopsykit.utils.file_handling import get_subject_dirs, is_excel_file
 from biopsykit.utils.time import tz
 
 __all__ = [
     "load_hr_phase_dict",
-    "load_hr_phase_dict_folder",
     "load_hr_phase_dict_csv",
+    "load_hr_phase_dict_folder",
     "write_hr_phase_dict",
     "write_hr_phase_dict_csv",
 ]
@@ -24,7 +26,7 @@ __all__ = [
 def load_hr_phase_dict(file_path: path_t, assert_format: Optional[bool] = True) -> HeartRatePhaseDict:
     """Load Excel file containing time series heart rate data of one subject.
 
-    The returned dictionary will be a :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`,
+    The returned dictionary will be a :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`,
     i.e., a dict with heart rate data from one subject split into phases (as exported by :func:`write_hr_phase_dict`
     or :func:`write_hr_phase_dict_csv`).
 
@@ -37,21 +39,21 @@ def load_hr_phase_dict(file_path: path_t, assert_format: Optional[bool] = True)
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`
+    :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`
         Dict with heart rate data split into phases
 
     Raises
     ------
     :exc:`~biopsykit.utils.exceptions.ValidationError`
-        if file in ``file_path`` is not a :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`
+        if file in ``file_path`` is not a :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`
         (if ``assert_format`` is ``True``)
     :exc:`~biopsykit.utils.exceptions.FileExtensionError`
         if file is no Excel file (`.xls` or `.xlsx`)
 
     See Also
     --------
-    ~biopsykit.utils.datatype_helper.HeartRatePhaseDict : Dictionary format
-    write_hr_phase_dict : Write :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` to file
+    ~biopsykit.utils.dtypes.HeartRatePhaseDict : Dictionary format
+    write_hr_phase_dict : Write :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` to file
 
     """
     # ensure pathlib
@@ -74,11 +76,10 @@ def load_hr_phase_dict(file_path: path_t, assert_format: Optional[bool] = True)
 def load_hr_phase_dict_folder(
     base_path: path_t, filename_pattern: str, subfolder_pattern: Optional[str] = None
 ) -> HeartRateSubjectDataDict:
-    """Load a folder with multiple :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` and concatenate them \
-    into a :obj:`~biopsykit.utils.datatype_helper.HeartRateSubjectDataDict`.
+    r"""Load a folder with multiple ``HeartRatePhaseDict`` and concatenate them  into a ``HeartRateSubjectDataDict``.
 
     This functions looks for all files that match the ``file_pattern`` in the folder specified by ``base_path``
-    and loads the files that are all expected to be :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`.
+    and loads the files that are all expected to be :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`.
 
     Subject IDs are extracted from the file name. Hence, ``file_pattern`` needs to be a regex
     including a capture group, e.g. "ecg_results_(\\w+).xlsx".
@@ -86,10 +87,10 @@ def load_hr_phase_dict_folder(
     Alternatively, if the files are stored in subfolders, the name pattern of these subfolders can be specified by
     ``subject_folder_pattern``. Then, it is expected that the subfolder names correspond to the subject IDs.
 
-    The returned dictionary will be a :obj:`~biopsykit.utils.datatype_helper.HeartRateSubjectDataDict`
+    The returned dictionary will be a :obj:`~biopsykit.utils.dtypes.HeartRateSubjectDataDict`
     with the following format:
 
-    { ``subject_id`` : :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` }
+    { ``subject_id`` : :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` }
 
 
     Parameters
@@ -97,7 +98,7 @@ def load_hr_phase_dict_folder(
     base_path : :class: `~pathlib.Path` or str
         path to top-level folder containing all subject folders
     filename_pattern : str
-        filename pattern of exported :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`.
+        filename pattern of exported :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`.
         Must be a regex string with capture group to extract subject IDs, or a regular regex string
         (without capture group) if ``subfolder_pattern`` is specified
     subfolder_pattern : str, optional
@@ -107,22 +108,22 @@ def load_hr_phase_dict_folder(
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.HeartRateSubjectDataDict`
-        :obj:`~biopsykit.utils.datatype_helper.HeartRateSubjectDataDict`, i.e., a dictionary with
-        :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` of multiple subjects
+    :obj:`~biopsykit.utils.dtypes.HeartRateSubjectDataDict`
+        :obj:`~biopsykit.utils.dtypes.HeartRateSubjectDataDict`, i.e., a dictionary with
+        :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` of multiple subjects
 
     Raises
     ------
     :exc:`~biopsykit.utils.exceptions.ValidationError`
         if any file that matches ``filename_pattern`` is not a
-        :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`
+        :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`
     :exc:`FileNotFoundError`
         if no files match ``filename_pattern`` or no subfolders match ``subfolder_pattern``
 
     See Also
     --------
     ~biopsykit.utils.file_handling.get_subject_dirs : Filter for subject subfolders in a given folder
-    load_hr_phase_dict : Load :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` for one subject
+    load_hr_phase_dict : Load :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` for one subject
 
     Examples
     --------
@@ -156,12 +157,10 @@ def load_hr_phase_dict_folder(
 
     dict_hr_subjects = {}
     if subfolder_pattern is None:
-        file_list = list(sorted(base_path.glob("*")))
+        file_list = sorted(base_path.glob("*"))
         file_list = [f for f in file_list if re.search(filename_pattern, f.name)]
         if len(file_list) == 0:
-            raise FileNotFoundError(
-                "No files matching the pattern '{}' found in {}.".format(filename_pattern, base_path)
-            )
+            raise FileNotFoundError(f"No files matching the pattern '{filename_pattern}' found in {base_path}.")
         for file in file_list:
             subject_id = re.findall(filename_pattern, file.name)[0]
             dict_hr_subjects[subject_id] = load_hr_phase_dict(file)
@@ -182,7 +181,7 @@ def _load_hr_phase_dict_single_subject(subject_dir: Path, filename_pattern: str)
     # first try to search for files with glob (assuming that a regex string without capture group was passed),
     # then try to search via regex search (assuming that a regex string with capture group was passed,
     # which should actually not be done if subfolder_pattern is passed)
-    file_list = list(sorted(subject_dir.glob(filename_pattern)))
+    file_list = sorted(subject_dir.glob(filename_pattern))
     if len(file_list) == 0:
         file_list = sorted(subject_dir.glob("*"))
         # then extract the ones that match
@@ -192,38 +191,38 @@ def _load_hr_phase_dict_single_subject(subject_dir: Path, filename_pattern: str)
         return load_hr_phase_dict(file_list[0])
     if len(file_list) > 1:
         warnings.warn(
-            'More than one file matching file pattern "{}" found in folder {}. '
-            "Trying to merge these files into one HeartRatePhaseDict".format(filename_pattern, subject_dir)
+            f'More than one file matching file pattern "{filename_pattern}" found in folder {subject_dir}. '
+            "Trying to merge these files into one HeartRatePhaseDict"
         )
         dict_hr = {}
         for file in file_list:
             dict_hr.update(load_hr_phase_dict(file))
         return dict_hr
 
-    print("No Heart Rate data for subject {}".format(subject_id))
+    print(f"No Heart Rate data for subject {subject_id}")
     return None
 
 
 def write_hr_phase_dict(hr_phase_dict: HeartRatePhaseDict, file_path: path_t):
-    """Write :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` to an Excel file.
+    """Write :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` to an Excel file.
 
-    The :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` is a dictionary with heart rate time
+    The :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` is a dictionary with heart rate time
     series data split into phases.
 
     Each of the phases in the dictionary will be a separate sheet in the Excel file.
 
     Parameters
     ----------
-    hr_phase_dict : :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`
-        a :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` containing pandas dataframes
+    hr_phase_dict : :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`
+        a :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` containing pandas dataframes
         with heart rate data
     file_path : :class:`~pathlib.Path` or str
         path to export file
 
     See Also
     --------
-    ~biopsykit.utils.datatype_helper.HeartRatePhaseDict : Dictionary format
-    load_hr_phase_dict : Load :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` written to file
+    ~biopsykit.utils.dtypes.HeartRatePhaseDict : Dictionary format
+    load_hr_phase_dict : Load :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` written to file
     ~biopsykit.io.write_pandas_dict_excel : Write dictionary with pandas dataframes to Excel file
 
     """
@@ -238,17 +237,17 @@ def write_hr_phase_dict(hr_phase_dict: HeartRatePhaseDict, file_path: path_t):
 
 
 def write_hr_phase_dict_csv(hr_phase_dict: HeartRatePhaseDict, folder_path: path_t, file_pattern: path_t):
-    """Write :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` to a series of csv files.
+    """Write :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` to a series of csv files.
 
-    The :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` is a dictionary with heart rate time
+    The :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` is a dictionary with heart rate time
     series data split into phases.
 
     Each of the phases in the dictionary will be a separate csv file.
 
     Parameters
     ----------
-    hr_phase_dict : :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`
-        a :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` containing pandas dataframes
+    hr_phase_dict : :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`
+        a :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` containing pandas dataframes
         with heart rate data
     folder_path : :class:`~pathlib.Path` or str
         folder path to export csv files
@@ -261,14 +260,14 @@ def write_hr_phase_dict_csv(hr_phase_dict: HeartRatePhaseDict, folder_path: path
     ValueError
         if ``file_pattern`` does not include a placeholder "{}" that can be filled with the phase name
     :exc:`~biopsykit.utils.exceptions.ValidationError`
-        if ``hr_phase_dict`` is not a :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`
+        if ``hr_phase_dict`` is not a :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`
     :exc:`~biopsykit.utils.exceptions.FileExtensionError`
         if ``file_pattern`` is no csv file
 
     See Also
     --------
-    ~biopsykit.utils.datatype_helper.HeartRatePhaseDict : Dictionary format
-    load_hr_phase_dict_csv : Load :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` written to csv files
+    ~biopsykit.utils.dtypes.HeartRatePhaseDict : Dictionary format
+    load_hr_phase_dict_csv : Load :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` written to csv files
 
     """
     # ensure pathlib
@@ -296,10 +295,9 @@ def load_hr_phase_dict_csv(
     phase_order: Optional[Sequence[str]] = None,
     assert_format: Optional[bool] = True,
 ) -> HeartRatePhaseDict:
-    """Load csv file containing time series heart rate data of one subject from folder and combine it into a \
-    :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`.
+    """Load csv file with time series HR data of one subject from folder and combine it into a ``HeartRatePhaseDict``.
 
-    The returned dictionary will be a :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`,
+    The returned dictionary will be a :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`,
     i.e., a dict with heart rate data from one subject split into phases (as exported by :func:`write_hr_phase_dict`).
 
     Parameters
@@ -310,7 +308,7 @@ def load_hr_phase_dict_csv(
         file pattern of the csv files. `file_pattern` must include a regex capture group (see Examples) which is used
         to extract the phase name from the file name.
     phase_order : list of str, optional
-        list of phase names to order resulting :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` or ``None``
+        list of phase names to order resulting :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` or ``None``
         to order phases according to the file name ordering in ``folder_path``.
         Default: ``None``
     assert_format : bool, optional
@@ -318,21 +316,21 @@ def load_hr_phase_dict_csv(
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`
+    :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`
         Dict with heart rate data split into phases
 
     Raises
     ------
     :exc:`~biopsykit.utils.exceptions.ValidationError`
-        if file in ``file_path`` is not a :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict`
+        if file in ``file_path`` is not a :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict`
         (if ``assert_format`` is ``True``)
     :exc:`~biopsykit.utils.exceptions.FileExtensionError`
         if file is no Excel file (`.xls` or `.xlsx`)
 
     See Also
     --------
-    ~biopsykit.utils.datatype_helper.HeartRatePhaseDict : Dictionary format
-    write_hr_phase_dict_csv : Write :obj:`~biopsykit.utils.datatype_helper.HeartRatePhaseDict` to a series of csv files
+    ~biopsykit.utils.dtypes.HeartRatePhaseDict : Dictionary format
+    write_hr_phase_dict_csv : Write :obj:`~biopsykit.utils.dtypes.HeartRatePhaseDict` to a series of csv files
 
     """
     # ensure pathlib
