@@ -1,29 +1,30 @@
 """Module for importing data recorded by NilsPod sensors."""
+
 import datetime
 import re
 import warnings
+from collections.abc import Sequence
 from pathlib import Path
-from typing import Dict, Optional, Sequence, Tuple, Union
+from typing import Literal, Optional, Union
 
 import numpy as np
 import pandas as pd
 from nilspodlib import Dataset, SyncedSession
-from typing_extensions import Literal
 
 from biopsykit.utils._datatype_validation_helper import _assert_file_extension, _assert_is_dir, _assert_is_dtype
-from biopsykit.utils._types import path_t
+from biopsykit.utils._types_internal import path_t
 from biopsykit.utils.time import tz
 
 COUNTER_INCONSISTENCY_HANDLING = Literal["raise", "warn", "ignore"]
 """Available behavior types when dealing with NilsPod counter inconsistencies."""
 
 __all__ = [
-    "load_dataset_nilspod",
-    "load_synced_session_nilspod",
-    "load_csv_nilspod",
-    "load_folder_nilspod",
     "check_nilspod_dataset_corrupted",
     "get_nilspod_dataset_corrupted_info",
+    "load_csv_nilspod",
+    "load_dataset_nilspod",
+    "load_folder_nilspod",
+    "load_synced_session_nilspod",
 ]
 
 
@@ -33,7 +34,7 @@ def load_dataset_nilspod(
     datastreams: Optional[Union[str, Sequence[str]]] = None,
     handle_counter_inconsistency: Optional[COUNTER_INCONSISTENCY_HANDLING] = "raise",
     **kwargs,
-) -> Tuple[pd.DataFrame, float]:
+) -> tuple[pd.DataFrame, float]:
     """Load NilsPod recording and convert into dataframe.
 
     To load a dataset either a :class:`~nilspodlib.dataset.Dataset` object (via ``dataset`` parameter)
@@ -138,7 +139,7 @@ def load_synced_session_nilspod(
     datastreams: Optional[Union[str, Sequence[str]]] = None,
     handle_counter_inconsistency: Optional[COUNTER_INCONSISTENCY_HANDLING] = "raise",
     **kwargs,
-) -> Tuple[pd.DataFrame, float]:
+) -> tuple[pd.DataFrame, float]:
     """Load a synchronized session of NilsPod recordings and convert into dataframes.
 
     Parameters
@@ -204,13 +205,13 @@ def load_synced_session_nilspod(
     # ensure pathlib
     folder_path = Path(folder_path)
 
-    nilspod_files = list(sorted(folder_path.glob("*.bin")))
+    nilspod_files = sorted(folder_path.glob("*.bin"))
     if len(nilspod_files) == 0:
         raise ValueError("No NilsPod files found in directory!")
 
     kwargs.setdefault("tz", kwargs.pop("timezone", tz))
     session = SyncedSession.from_folder_path(folder_path, **kwargs)
-    session.align_to_syncregion(inplace=True)
+    session = session.align_to_syncregion()
 
     _handle_counter_inconsistencies_session(session, handle_counter_inconsistency)
     if isinstance(datastreams, str):
@@ -233,7 +234,7 @@ def _handle_counter_inconsistencies_dataset(
     idxs_corrupted = np.where(np.diff(dataset.counter) < 1)[0]
     # edge case: check if only last sample is corrupted. if yes, cut last sample
     if len(idxs_corrupted) == 1 and (idxs_corrupted == len(dataset.counter) - 2):
-        dataset.cut(start=0, stop=idxs_corrupted[0], inplace=True)
+        dataset = dataset.cut(start=0, stop=idxs_corrupted[0])
     elif len(idxs_corrupted) > 1:
         if handle_counter_inconsistency == "raise":
             raise ValueError("Error loading dataset. Counter not monotonously increasing!")
@@ -252,7 +253,7 @@ def _handle_counter_inconsistencies_session(
     idxs_corrupted = np.where(np.diff(session.counter) < 1)[0]
     # edge case: check if only last sample is corrupted. if yes, cut last sample
     if len(idxs_corrupted) == 1 and (idxs_corrupted == len(session.counter) - 2):
-        session.cut(start=0, stop=idxs_corrupted[0], inplace=True)
+        session = session.cut(start=0, stop=idxs_corrupted[0])
     elif len(idxs_corrupted) > 1:
         if handle_counter_inconsistency == "raise":
             raise ValueError("Error loading session. Counter not monotonously increasing!")
@@ -269,7 +270,7 @@ def load_csv_nilspod(
     timezone: Optional[Union[datetime.tzinfo, str]] = tz,
     filename_regex: Optional[str] = None,
     time_regex: Optional[str] = None,
-) -> Tuple[pd.DataFrame, float]:
+) -> tuple[pd.DataFrame, float]:
     r"""Convert a csv file recorded by NilsPod into a dataframe.
 
     By default, this function expects the file name to have the following pattern:
@@ -367,7 +368,7 @@ def _convert_index(df: pd.DataFrame, start_time: Sequence[str], time_regex: str)
 
 def load_folder_nilspod(
     folder_path: path_t, phase_names: Optional[Sequence[str]] = None, **kwargs
-) -> Tuple[Dict[str, pd.DataFrame], float]:
+) -> tuple[dict[str, pd.DataFrame], float]:
     """Load all NilsPod datasets from one folder, convert them into dataframes, and combine them into a dictionary.
 
     This function can for example be used when single NilsPod sessions (datasets) were recorded
@@ -419,7 +420,7 @@ def load_folder_nilspod(
     _assert_is_dir(folder_path)
 
     # look for all NilsPod binary files in the folder
-    dataset_list = list(sorted(folder_path.glob("*.bin")))
+    dataset_list = sorted(folder_path.glob("*.bin"))
     if len(dataset_list) == 0:
         raise ValueError(f"No NilsPod files found in folder {folder_path}!")
     if phase_names is None:
@@ -463,7 +464,7 @@ def check_nilspod_dataset_corrupted(dataset: Dataset) -> bool:
     return np.where(np.diff(dataset.counter) != 1.0)[0].size != 0
 
 
-def get_nilspod_dataset_corrupted_info(dataset: Dataset, file_path: path_t) -> Dict:
+def get_nilspod_dataset_corrupted_info(dataset: Dataset, file_path: path_t) -> dict:
     """Get information about the corruption state of a NilsPod dataset.
 
     Corruption information include the information:
@@ -501,10 +502,7 @@ def get_nilspod_dataset_corrupted_info(dataset: Dataset, file_path: path_t) -> D
     keys = ["name", "percent_corrupt", "condition"]
     dict_res = dict.fromkeys(keys)
     re_groups = re.search(nilspod_file_pattern, file_path.name)
-    if re_groups is not None:
-        name = re_groups.group(1)
-    else:
-        name = file_path.name
+    name = re_groups.group(1) if re_groups is not None else file_path.name
     dict_res["name"] = name
     if not check_nilspod_dataset_corrupted(dataset):
         dict_res["condition"] = "fine"
