@@ -1,4 +1,5 @@
 """Module with functions to compute metadata information."""
+
 from biopsykit.metadata.metadata import bmi, gender_counts, whr
 
-__all__ = ["bmi", "whr", "gender_counts"]
+__all__ = ["bmi", "gender_counts", "whr"]
