@@ -1,4 +1,5 @@
 """Module with classes representing different psychological protocols."""
+
 from biopsykit.protocols import plotting
 from biopsykit.protocols.base import BaseProtocol
 from biopsykit.protocols.car import CAR
@@ -6,4 +7,4 @@ from biopsykit.protocols.cft import CFT
 from biopsykit.protocols.mist import MIST
 from biopsykit.protocols.tsst import TSST
 
-__all__ = ["BaseProtocol", "CFT", "CAR", "MIST", "TSST", "plotting"]
+__all__ = ["CAR", "CFT", "MIST", "TSST", "BaseProtocol", "plotting"]
