@@ -1,4 +1,5 @@
 """Module with functions and utility functions to compute questionnaires."""
+
 from biopsykit.questionnaires import utils
 from biopsykit.questionnaires.questionnaires import (
     abi,
@@ -55,6 +56,7 @@ from biopsykit.questionnaires.questionnaires import (
     sop,
     ssgs,
     sss,
+    sssq,
     stadi,
     stai_short,
     state_rumination,
@@ -79,10 +81,10 @@ __all__ = [
     "asku",
     "asq",
     "asq_mod",
-    "bfi_k",
-    "bfi_10",
-    "bidr",
     "besaa",
+    "bfi_10",
+    "bfi_k",
+    "bidr",
     "brief_cope",
     # "ceca",
     "cesd",
@@ -95,8 +97,8 @@ __all__ = [
     "fscrs",
     "ghq",
     "hads",
-    "idq_pre_scan",
     "idq_post_scan",
+    "idq_pre_scan",
     "ie_4",
     "kab",
     "kkg",
@@ -127,12 +129,13 @@ __all__ = [
     "sop",
     "ssgs",
     "sss",
-    "swb",
+    "sssq",
     "stadi",
     "stai_short",
     "state_rumination",
     "svf_42",
     "svf_120",
+    "swb",
     "swls",
     "tb",
     "tics_l",
