@@ -1,12 +1,13 @@
 """Module containing utility functions for manipulating and processing questionnaire data."""
+
 import re
 import warnings
+from collections.abc import Sequence
 from inspect import getmembers, isfunction
-from typing import Any, Dict, Optional, Sequence, Tuple, Union
+from typing import Any, Literal, Optional, Union
 
 import numpy as np
 import pandas as pd
-from typing_extensions import Literal
 
 from biopsykit.utils._datatype_validation_helper import _assert_is_dtype, _assert_len_list, _assert_value_range
 from biopsykit.utils.dataframe_handling import wide_to_long as wide_to_long_utils
@@ -14,14 +15,14 @@ from biopsykit.utils.dataframe_handling import wide_to_long as wide_to_long_util
 __all__ = [
     "bin_scale",
     "compute_scores",
-    "crop_scale",
     "convert_scale",
+    "crop_scale",
     "find_cols",
-    "zero_pad_columns",
+    "get_supported_questionnaires",
     "invert",
     "to_idx",
     "wide_to_long",
-    "get_supported_questionnaires",
+    "zero_pad_columns",
 ]
 
 
@@ -32,7 +33,7 @@ def find_cols(
     ends_with: Optional[str] = None,
     contains: Optional[str] = None,
     zero_pad_numbers: Optional[bool] = True,
-) -> Tuple[pd.DataFrame, Sequence[str]]:
+) -> tuple[pd.DataFrame, Sequence[str]]:
     r"""Find columns in dataframe that match a specific pattern.
 
     This function is useful to find all columns that belong to a questionnaire. Column names can be filtered based on
@@ -163,7 +164,7 @@ def zero_pad_columns(data: pd.DataFrame, inplace: Optional[bool] = False) -> Opt
     nums = [c[0] if len(c) > 0 else "" for c in nums]
     if len(nums) == 0:
         return pd.DataFrame()
-    zfill_num = max(max(list(map(len, nums))), 2)
+    zfill_num = max(*list(map(len, nums)), 2)
 
     data.columns = [re.sub(r"(\d+)$", lambda m: m.group(1).zfill(zfill_num), c) for c in data.columns]
 
@@ -302,8 +303,8 @@ def _invert_dataframe(
 
 def _invert_subscales(
     data: pd.DataFrame,
-    subscales: Dict[str, Sequence[Union[str, int]]],
-    idx_dict: Dict[str, Sequence[int]],
+    subscales: dict[str, Sequence[Union[str, int]]],
+    idx_dict: dict[str, Sequence[int]],
     score_range: Sequence[int],
 ) -> pd.DataFrame:
     """Invert questionnaire scores from a dictionary of questionnaire subscales.
@@ -411,11 +412,10 @@ def _convert_scale_dataframe(
 ) -> pd.DataFrame:
     if cols is None:
         data.iloc[:, :] = data.iloc[:, :] + offset
-    else:
-        if isinstance(cols[0], int):
-            data.iloc[:, cols] = data.iloc[:, cols] + offset
-        elif isinstance(cols[0], str):
-            data.loc[:, cols] = data.loc[:, cols] + offset
+    elif isinstance(cols[0], int):
+        data.iloc[:, cols] = data.iloc[:, cols] + offset
+    elif isinstance(cols[0], str):
+        data.loc[:, cols] = data.loc[:, cols] + offset
 
     return data
 
@@ -452,10 +452,10 @@ def crop_scale(
         data = data.copy()
 
     if set_nan:
-        data.mask((data < score_range[0]) | (data > score_range[1]), inplace=True)
+        data.mask((data < score_range[0]) | (data > score_range[1]), inplace=True)  # noqa: PD002
     else:
-        data.mask((data < score_range[0]), other=score_range[0], inplace=True)
-        data.mask((data > score_range[1]), other=score_range[1], inplace=True)
+        data.mask((data < score_range[0]), other=score_range[0], inplace=True)  # noqa: PD002
+        data.mask((data > score_range[1]), other=score_range[1], inplace=True)  # noqa: PD002
 
     if inplace:
         return None
@@ -521,8 +521,13 @@ def bin_scale(
 
     if not inplace:
         data = data.copy()
+        data = data.astype("Int64")
+    else:
+        # shady inplace dtype conversion
+        for col in data.columns:
+            data[col] = data[col].astype("Int64")
 
-    # set "labels" argument to False, but only if is wasn't specified by the user yet
+    # set "labels" argument to False, but only if it wasn't specified by the user yet
     kwargs["labels"] = kwargs.get("labels", False)
     if isinstance(data, pd.Series):
         bins_c = _get_bins(data, bins, None, first_min, last_max)
@@ -534,15 +539,15 @@ def bin_scale(
     for col in cols:
         bins_c = _get_bins(data, bins, col, first_min, last_max)
         if isinstance(col, int):
-            c = pd.cut(data.iloc[:, col], bins=bins_c, **kwargs)
+            c = pd.cut(data.iloc[:, col], bins=bins_c, **kwargs).astype("Int64")
             data.iloc[:, col] = c
         else:
-            c = pd.cut(data.loc[:, col], bins=bins_c, **kwargs)
+            c = pd.cut(data.loc[:, col], bins=bins_c, **kwargs).astype("Int64")
             data.loc[:, col] = c
 
     if inplace:
         return None
-    return data
+    return data.astype("Int64")
 
 
 def wide_to_long(data: pd.DataFrame, quest_name: str, levels: Union[str, Sequence[str]]) -> pd.DataFrame:
@@ -584,8 +589,8 @@ def wide_to_long(data: pd.DataFrame, quest_name: str, levels: Union[str, Sequenc
 
 def compute_scores(
     data: pd.DataFrame,
-    quest_dict: Dict[str, Union[Sequence[str], pd.Index]],
-    quest_kwargs: Optional[Dict[str, Dict[str, Any]]] = None,
+    quest_dict: dict[str, Union[Sequence[str], pd.Index]],
+    quest_kwargs: Optional[dict[str, dict[str, Any]]] = None,
 ) -> pd.DataFrame:
     """Compute questionnaire scores from dataframe.
 
@@ -635,36 +640,37 @@ def compute_scores(
 
     for score, columns in quest_dict.items():
         score_orig = score
-        score = score.lower()
+        score = score.lower()  # noqa: PLW2901
         suffix = None
         if "-" in score:
             score_split = score.split("-")
-            score = score_split[0]
+            score = score_split[0]  # noqa: PLW2901
             suffix = score_split[1]
 
         if score not in quest_funcs:
             raise ValueError(
-                "Unknown questionnaire '{}'! Call "
+                f"Unknown questionnaire '{score}'! Call "
                 "'biopsykit.questionnaires.utils.get_supported_questionnaires()' "
-                "to get a list of all supported questionnaires.".format(score)
+                "to get a list of all supported questionnaires."
             )
         kwargs = quest_kwargs.get(score_orig, {})
+
         try:
             df = quest_funcs[score](data[columns], **kwargs)
         except TypeError as e:
             raise TypeError(
-                "Error computing questionnaire '{}'. The computation failed with the following "
-                "error: \n\n{}.".format(score, str(e))
+                f"Error computing questionnaire '{score}'. The computation failed with the following "
+                f"error: \n\n{e!s}."
             ) from e
 
         if suffix is not None:
-            df.columns = ["{}_{}".format(col, suffix) for col in df.columns]
+            df.columns = [f"{col}_{suffix}" for col in df.columns]
         df_scores = df_scores.join(df)
 
     return df_scores
 
 
-def get_supported_questionnaires() -> Dict[str, str]:
+def get_supported_questionnaires() -> dict[str, str]:
     """List all supported (i.e., implemented) questionnaires.
 
     Returns
@@ -692,9 +698,9 @@ def get_supported_questionnaires() -> Dict[str, str]:
 def _compute_questionnaire_subscales(
     data: pd.DataFrame,
     score_name: str,
-    subscales: Dict[str, Sequence[Union[str, int]]],
+    subscales: dict[str, Sequence[Union[str, int]]],
     agg_type: Optional[Literal["sum", "mean"]] = "sum",
-) -> Dict[str, pd.Series]:
+) -> dict[str, pd.Series]:
     """Compute questionnaire subscales (helper function).
 
     Parameters
@@ -731,7 +737,7 @@ def _compute_questionnaire_subscales(
                 "column indices (list of integers)!"
             )
 
-        out["{}_{}".format(score_name, key)] = score
+        out[f"{score_name}_{key}"] = score
 
     return out
 
@@ -767,7 +773,6 @@ def _get_bins(
     first_min: Optional[bool] = False,
     last_max: Optional[bool] = False,
 ) -> Union[int, Sequence[float]]:
-
     if isinstance(bins, (int, pd.IntervalIndex)):
         return bins
 
@@ -777,12 +782,12 @@ def _get_bins(
     if first_min:
         min_val = _bin_scale_get_min_val(data, col)
         if min_val < min(bins):
-            bins = [min_val - 0.01] + bins
+            bins = [min_val - 0.01, *bins]
 
     if last_max:
         max_val = _bin_scale_get_max_val(data, col)
         if max_val > max(bins):
-            bins = bins + [max_val + 0.01]
+            bins = [*bins, max_val + 0.01]
 
     return bins
 
