@@ -1,9 +1,12 @@
 """Functions for processing saliva data and computing established features (AUC, slope, maximum increase, ...)."""
+
 import warnings
-from typing import Dict, List, Optional, Sequence, Tuple, Union
+from collections.abc import Sequence
+from typing import Optional, Union
 
 import numpy as np
 import pandas as pd
+import scipy.stats as ss
 
 from biopsykit.saliva.utils import (
     _check_sample_times,
@@ -12,7 +15,7 @@ from biopsykit.saliva.utils import (
     _get_sample_times,
     _remove_s0,
 )
-from biopsykit.utils.datatype_helper import (
+from biopsykit.utils.dtypes import (
     SalivaFeatureDataFrame,
     SalivaMeanSeDataFrame,
     SalivaRawDataFrame,
@@ -30,7 +33,7 @@ def max_value(
     data: SalivaRawDataFrame,
     saliva_type: Optional[Union[str, Sequence[str]]] = "cortisol",
     remove_s0: Optional[bool] = False,
-) -> Union[SalivaFeatureDataFrame, Dict[str, SalivaFeatureDataFrame]]:
+) -> Union[SalivaFeatureDataFrame, dict[str, SalivaFeatureDataFrame]]:
     """Compute maximum value.
 
     The output feature name will be ``max_val``, preceded by the name of the saliva type to allow better
@@ -38,7 +41,7 @@ def max_value(
 
     Parameters
     ----------
-    data : :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+    data : :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
         saliva data in `SalivaRawDataFrame` format
     saliva_type : str or list of str
         saliva type or list of saliva types to compute features on
@@ -47,13 +50,13 @@ def max_value(
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SalivaFeatureDataFrame` or dict of such
+    :obj:`~biopsykit.utils.dtypes.SalivaFeatureDataFrame` or dict of such
         dataframe containing the computed features, or a dict of such if ``saliva_type`` is a list
 
     Raises
     ------
     :exc:`~biopsykit.utils.exceptions.ValidationError`
-        if ``data`` is not a :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+        if ``data`` is not a :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
 
     """
     # check input
@@ -64,7 +67,7 @@ def max_value(
         for saliva in saliva_type:
             saliva_col = [saliva]
             if "time" in data:
-                saliva_col = saliva_col + ["time"]
+                saliva_col = [*saliva_col, "time"]
             dict_result[saliva] = max_value(
                 data[saliva_col],
                 saliva_type=saliva,
@@ -84,7 +87,7 @@ def max_value(
 
     out = pd.DataFrame(
         max_val,
-        columns=["{}_max_val".format(saliva_type)],
+        columns=[f"{saliva_type}_max_val"],
         index=max_val.index,
     )
     out.columns.name = "saliva_feature"
@@ -98,7 +101,7 @@ def initial_value(
     data: SalivaRawDataFrame,
     saliva_type: Optional[Union[str, Sequence[str]]] = "cortisol",
     remove_s0: Optional[bool] = False,
-) -> Union[SalivaFeatureDataFrame, Dict[str, SalivaFeatureDataFrame]]:
+) -> Union[SalivaFeatureDataFrame, dict[str, SalivaFeatureDataFrame]]:
     """Compute initial saliva sample.
 
     The output feature name will be ``ini_val``, preceded by the name of the saliva type to allow better
@@ -106,7 +109,7 @@ def initial_value(
 
     Parameters
     ----------
-    data : :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+    data : :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
         saliva data in `SalivaRawDataFrame` format
     saliva_type : str or list of str
         saliva type or list of saliva types to compute features on
@@ -115,13 +118,13 @@ def initial_value(
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SalivaFeatureDataFrame` or dict of such
+    :obj:`~biopsykit.utils.dtypes.SalivaFeatureDataFrame` or dict of such
         dataframe containing the computed features, or a dict of such if ``saliva_type`` is a list
 
     Raises
     ------
     :exc:`~biopsykit.utils.exceptions.ValidationError`
-        if ``data`` is not a :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+        if ``data`` is not a :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
 
     """
     # check input
@@ -132,7 +135,7 @@ def initial_value(
         for saliva in saliva_type:
             saliva_col = [saliva]
             if "time" in data:
-                saliva_col = saliva_col + ["time"]
+                saliva_col = [*saliva_col, "time"]
             dict_result[saliva] = initial_value(
                 data[saliva_col],
                 saliva_type=saliva,
@@ -150,7 +153,7 @@ def initial_value(
 
     out = pd.DataFrame(
         ini_val.values,
-        columns=["{}_ini_val".format(saliva_type)],
+        columns=[f"{saliva_type}_ini_val"],
         index=ini_val.index,
     )
     out.columns.name = "saliva_feature"
@@ -165,7 +168,7 @@ def max_increase(
     saliva_type: Optional[Union[str, Sequence[str]]] = "cortisol",
     remove_s0: Optional[bool] = False,
     percent: Optional[bool] = False,
-) -> Union[SalivaFeatureDataFrame, Dict[str, SalivaFeatureDataFrame]]:
+) -> Union[SalivaFeatureDataFrame, dict[str, SalivaFeatureDataFrame]]:
     """Compute maximum increase between first saliva sample and all others.
 
     The maximum increase (`max_inc`) is defined as the difference between the `first` sample and the maximum of
@@ -182,7 +185,7 @@ def max_increase(
 
     Parameters
     ----------
-    data : :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+    data : :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
         saliva data in `SalivaRawDataFrame` format
     saliva_type : str or list of str
         saliva type or list of saliva types to compute features on
@@ -193,13 +196,13 @@ def max_increase(
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SalivaFeatureDataFrame` or dict of such
+    :obj:`~biopsykit.utils.dtypes.SalivaFeatureDataFrame` or dict of such
         dataframe containing the computed features, or a dict of such if ``saliva_type`` is a list
 
     Raises
     ------
     :exc:`~biopsykit.utils.exceptions.ValidationError`
-        if ``data`` is not a :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+        if ``data`` is not a :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
 
     """
     # check input
@@ -210,7 +213,7 @@ def max_increase(
         for saliva in saliva_type:
             saliva_col = [saliva]
             if "time" in data:
-                saliva_col = saliva_col + ["time"]
+                saliva_col = [*saliva_col, "time"]
             dict_result[saliva] = max_increase(
                 data[saliva_col],
                 saliva_type=saliva,
@@ -231,7 +234,7 @@ def max_increase(
 
     out = pd.DataFrame(
         max_inc,
-        columns=["{}_max_inc_percent".format(saliva_type) if percent else "{}_max_inc".format(saliva_type)],
+        columns=[f"{saliva_type}_max_inc_percent" if percent else f"{saliva_type}_max_inc"],
         index=max_inc.index,
     )
     out.columns.name = "saliva_feature"
@@ -247,12 +250,12 @@ def auc(
     remove_s0: Optional[bool] = False,
     compute_auc_post: Optional[bool] = False,
     sample_times: Optional[Union[np.ndarray, Sequence[int], str]] = None,
-) -> Union[SalivaFeatureDataFrame, Dict[str, SalivaFeatureDataFrame]]:
+) -> Union[SalivaFeatureDataFrame, dict[str, SalivaFeatureDataFrame]]:
     r"""Compute area-under-the-curve (AUC) for saliva samples.
 
     The area-under-the-curve is computed according to Pruessner et al. (2003) using the trapezoidal rule
     (:func:`numpy.trapz`). To compute an AUC the saliva time points are required in minutes. They can either be part of
-    the :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame` (`time` column) or can be supplied as extra
+    the :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame` (`time` column) or can be supplied as extra
     parameter (``sample_times``).
 
     Pruessner defined two types of AUC, which are computed by default:
@@ -277,7 +280,7 @@ def auc(
 
     Parameters
     ----------
-    data : :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+    data : :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
         saliva data in `SalivaRawDataFrame` format
     saliva_type : str or list of str
         saliva type or list of saliva types to compute features on
@@ -298,19 +301,19 @@ def auc(
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SalivaFeatureDataFrame` or dict of such
+    :obj:`~biopsykit.utils.dtypes.SalivaFeatureDataFrame` or dict of such
         dataframe containing the computed features, or a dict of such if ``saliva_type`` is a list
 
     Raises
     ------
     :exc:`~biopsykit.utils.exceptions.ValidationError`
-        if ``data`` is not a :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+        if ``data`` is not a :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
 
     References
     ----------
     Pruessner, J. C., Kirschbaum, C., Meinlschmid, G., & Hellhammer, D. H. (2003).
     Two formulas for computation of the area under the curve represent measures of total hormone concentration
-    versus time-dependent change. Psychoneuroendocrinology, 28(7), 916–931.
+    versus time-dependent change. Psychoneuroendocrinology, 28(7), 916-931.
     https://doi.org/10.1016/S0306-4530(02)00108-7
 
     """
@@ -322,7 +325,7 @@ def auc(
         for saliva in saliva_type:
             saliva_col = [saliva]
             if "time" in data:
-                saliva_col = saliva_col + ["time"]
+                saliva_col = [*saliva_col, "time"]
             dict_result[saliva] = auc(
                 data[saliva_col],
                 saliva_type=saliva,
@@ -341,14 +344,14 @@ def auc(
     data = data[[saliva_type]].unstack(level="sample")
 
     auc_data = {
-        "auc_g": np.trapz(data, sample_times),
-        "auc_i": np.trapz(data.sub(data.iloc[:, 0], axis=0), sample_times),
+        "auc_g": np.trapezoid(data, sample_times),
+        "auc_i": np.trapezoid(data.sub(data.iloc[:, 0], axis=0), sample_times),
     }
 
     if compute_auc_post:
         auc_data = _auc_compute_auc_post(data, auc_data, sample_times)
 
-    out = pd.DataFrame(auc_data, index=data.index).add_prefix("{}_".format(saliva_type))
+    out = pd.DataFrame(auc_data, index=data.index).add_prefix(f"{saliva_type}_")
     out.columns.name = "saliva_feature"
 
     # check output
@@ -358,8 +361,8 @@ def auc(
 
 
 def _auc_compute_auc_post(
-    data: SalivaRawDataFrame, auc_data: Dict[str, np.ndarray], sample_times: np.ndarray
-) -> Dict[str, np.ndarray]:
+    data: SalivaRawDataFrame, auc_data: dict[str, np.ndarray], sample_times: np.ndarray
+) -> dict[str, np.ndarray]:
     idxs_post = None
     if sample_times.ndim == 1:
         idxs_post = np.where(sample_times >= 0)[0]
@@ -370,17 +373,17 @@ def _auc_compute_auc_post(
         )
     if idxs_post is not None:
         data_post = data.iloc[:, idxs_post]
-        auc_data["auc_i_post"] = np.trapz(data_post.sub(data_post.iloc[:, 0], axis=0), sample_times[idxs_post])
+        auc_data["auc_i_post"] = np.trapezoid(data_post.sub(data_post.iloc[:, 0], axis=0), sample_times[idxs_post])
     return auc_data
 
 
 def slope(
     data: SalivaRawDataFrame,
-    sample_labels: Optional[Union[Tuple, Sequence]] = None,
-    sample_idx: Optional[Union[Tuple[int, int], Sequence[int]]] = None,
+    sample_labels: Optional[Union[tuple, Sequence]] = None,
+    sample_idx: Optional[Union[tuple[int, int], Sequence[int]]] = None,
     saliva_type: Optional[Union[str, Sequence[str]]] = "cortisol",
     sample_times: Optional[Sequence[int]] = None,
-) -> Union[SalivaFeatureDataFrame, Dict[str, SalivaFeatureDataFrame]]:
+) -> Union[SalivaFeatureDataFrame, dict[str, SalivaFeatureDataFrame]]:
     """Compute the slope between two saliva samples.
 
     The samples to compute the slope can either be specified by `index` (parameter `sample_idx`) [0, num_of_samples-1]
@@ -392,7 +395,7 @@ def slope(
 
     Parameters
     ----------
-    data : :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+    data : :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
         saliva data in `SalivaRawDataFrame` format
     saliva_type : str or list of str
         saliva type or list of saliva types to compute features on
@@ -414,7 +417,7 @@ def slope(
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SalivaFeatureDataFrame` or dict of such
+    :obj:`~biopsykit.utils.dtypes.SalivaFeatureDataFrame` or dict of such
         dataframe containing the computed features, or a dict of such if ``saliva_type`` is a list
 
     Raises
@@ -422,7 +425,7 @@ def slope(
     IndexError
         if invalid `sample_labels` or `sample_idx` is provided
     :exc:`~biopsykit.utils.exceptions.ValidationError`
-        if ``data`` is not a :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+        if ``data`` is not a :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
 
     """
     # check input
@@ -439,7 +442,7 @@ def slope(
         for saliva in saliva_type:
             saliva_col = [saliva]
             if "time" in data:
-                saliva_col = saliva_col + ["time"]
+                saliva_col = [*saliva_col, "time"]
             dict_result[saliva] = slope(
                 data[saliva_col],
                 sample_labels=sample_labels,
@@ -476,7 +479,7 @@ def standard_features(
     saliva_type: Optional[Union[str, Sequence[str]]] = "cortisol",
     group_cols: Optional[Union[str, Sequence[str]]] = None,
     keep_index: Optional[bool] = True,
-) -> Union[SalivaFeatureDataFrame, Dict[str, SalivaFeatureDataFrame]]:
+) -> Union[SalivaFeatureDataFrame, dict[str, SalivaFeatureDataFrame]]:
     """Compute a set of `standard features` on saliva data.
 
     The following list of features is computed:
@@ -497,7 +500,7 @@ def standard_features(
 
     Parameters
     ----------
-    data : :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+    data : :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
         saliva data in `SalivaRawDataFrame` format
     saliva_type : str or list of str
         saliva type or list of saliva types to compute features on
@@ -512,13 +515,13 @@ def standard_features(
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SalivaFeatureDataFrame` or dict of such
+    :obj:`~biopsykit.utils.dtypes.SalivaFeatureDataFrame` or dict of such
         dataframe containing the computed features, or a dict of such if ``saliva_type`` is a list
 
     Raises
     ------
     :exc:`~biopsykit.utils.exceptions.ValidationError`
-        if ``data`` is not a :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+        if ``data`` is not a :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
     :exc:`~biopsykit.utils.exceptions.DataFrameTransformationError`
         if ``keep_index`` is ``True``, but applying the old index fails
 
@@ -531,7 +534,7 @@ def standard_features(
         for saliva in saliva_type:
             saliva_col = [saliva]
             if "time" in data:
-                saliva_col = saliva_col + ["time"]
+                saliva_col = [*saliva_col, "time"]
             dict_result[saliva] = standard_features(data[saliva_col], saliva_type=saliva)
         return dict_result
 
@@ -543,10 +546,10 @@ def standard_features(
         .agg(
             [
                 np.argmax,
-                pd.DataFrame.mean,
-                pd.DataFrame.std,
-                pd.DataFrame.skew,
-                pd.DataFrame.kurt,
+                "mean",
+                "std",
+                ss.skew,
+                ss.kurtosis,
             ],
         )
     )
@@ -558,13 +561,13 @@ def standard_features(
                 "DataFrame transformation failed: Unable to keep old dataframe index because index does not match with "
                 "output data shape, possibly because 'groupby' recuded the index. "
                 "Consider setting 'keep_index' to 'False'. "
-                "The exact error was:\n\n{}".format(str(e))
+                f"The exact error was:\n\n{e!s}"
             ) from e
 
     # drop 'saliva_type' multiindex column and add as prefix to columns to ensure consistent naming with
     # the other saliva functions
     out.columns = out.columns.droplevel(0)
-    out = out.add_prefix("{}_".format(saliva_type))
+    out = out.add_prefix(f"{saliva_type}_")
     out.columns.name = "saliva_feature"
 
     # check output
@@ -576,14 +579,14 @@ def standard_features(
 def mean_se(
     data: SalivaRawDataFrame,
     saliva_type: Optional[Union[str, Sequence[str]]] = "cortisol",
-    group_cols: Optional[Union[str, List[str]]] = None,
+    group_cols: Optional[Union[str, list[str]]] = None,
     remove_s0: Optional[bool] = False,
-) -> Union[SalivaMeanSeDataFrame, Dict[str, SalivaMeanSeDataFrame]]:
+) -> Union[SalivaMeanSeDataFrame, dict[str, SalivaMeanSeDataFrame]]:
     """Compute mean and standard error per saliva sample.
 
     Parameters
     ----------
-    data : :class:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+    data : :class:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
         saliva data in `SalivaRawDataFrame` format
     saliva_type : str or list of str
         saliva type or list of saliva types to compute features on
@@ -596,13 +599,13 @@ def mean_se(
 
     Returns
     -------
-    :class:`~biopsykit.utils.datatype_helper.SalivaMeanSeDataFrame`
+    :class:`~biopsykit.utils.dtypes.SalivaMeanSeDataFrame`
         dataframe with mean and standard error per saliva sample or a dict of such if ``saliva_type`` is a list
 
     Raises
     ------
     :exc:`~biopsykit.utils.exceptions.ValidationError`
-        if ``data`` is not a :obj:`~biopsykit.utils.datatype_helper.SalivaRawDataFrame`
+        if ``data`` is not a :obj:`~biopsykit.utils.dtypes.SalivaRawDataFrame`
 
 
     """
@@ -614,7 +617,7 @@ def mean_se(
         for biomarker in saliva_type:
             biomarker_cols = [biomarker]
             if "time" in data:
-                biomarker_cols = ["time"] + biomarker_cols
+                biomarker_cols = ["time", *biomarker_cols]
             dict_result[biomarker] = mean_se(data[biomarker_cols], saliva_type=biomarker, remove_s0=remove_s0)
         return dict_result
 
@@ -628,9 +631,9 @@ def mean_se(
     if "time" in data.columns and "time" not in group_cols:
         # add 'time' column to grouper if it's in the data and wasn't added yet because otherwise
         # we would loose this column
-        group_cols = group_cols + ["time"]
+        group_cols = [*group_cols, "time"]
 
-    data_mean_se = data.groupby(group_cols).agg([np.mean, se])[saliva_type]
+    data_mean_se = data.groupby(group_cols).agg(["mean", se])[saliva_type]
     is_saliva_mean_se_dataframe(data_mean_se)
 
     return _SalivaMeanSeDataFrame(data_mean_se)
