@@ -1,4 +1,5 @@
 """Module for generating Activity Counts from raw acceleration signals."""
+
 import datetime
 from typing import Optional, Union
 
@@ -7,9 +8,9 @@ import pandas as pd
 import pytz
 from scipy import signal
 
-from biopsykit.utils._types import arr_t
+from biopsykit.utils._types_internal import arr_t
 from biopsykit.utils.array_handling import add_datetime_index, downsample, sanitize_input_nd
-from biopsykit.utils.datatype_helper import is_acc1d_dataframe, is_acc3d_dataframe
+from biopsykit.utils.dtypes import is_acc1d_dataframe, is_acc3d_dataframe
 from biopsykit.utils.time import tz
 
 
@@ -25,7 +26,7 @@ class ActivityCounts:
     References
     ----------
     Brønd, J. C., Andersen, L. B., & Arvidsson, D. (2017). Generating ActiGraph Counts from Raw Acceleration Recorded
-    by an Alternative Monitor. *Medicine and Science in Sports and Exercise*, 49(11), 2351–2360.
+    by an Alternative Monitor. *Medicine and Science in Sports and Exercise*, 49(11), 2351-2360.
     https://doi.org/10.1249/MSS.0000000000001344
 
     """
@@ -181,6 +182,6 @@ class ActivityCounts:
         arr = self._digitize_8bit(arr)
         arr = self._accumulate_second_bins(arr)
         if start_idx is not None:
-            arr = add_datetime_index(arr, start_idx, 1 / 60, column_name=["activity_counts"])
+            arr = add_datetime_index(arr, start_idx, 1, column_name=["activity_counts"])
 
         return arr
