@@ -1,5 +1,6 @@
 """Extract features from static moments of IMU data."""
-from typing import Optional, Tuple, Union
+
+from typing import Optional, Union
 
 import numpy as np
 import pandas as pd
@@ -83,12 +84,12 @@ def compute_features(
     # feature_dict.update(dict_ori)
 
     for dur, suffix in zip([durations, durations_60], ["", "_60"]):
-        feature_dict["sm_number{}".format(suffix)] = len(dur)
-        feature_dict["sm_max{}".format(suffix)] = np.max(dur)
-        feature_dict["sm_median{}".format(suffix)] = np.median(dur)
-        feature_dict["sm_mean{}".format(suffix)] = np.mean(dur)
-        feature_dict["sm_std{}".format(suffix)] = np.std(dur, ddof=1)
-        feature_dict["sm_skewness{}".format(suffix)] = skew(dur)
+        feature_dict[f"sm_number{suffix}"] = len(dur)
+        feature_dict[f"sm_max{suffix}"] = np.max(dur)
+        feature_dict[f"sm_median{suffix}"] = np.median(dur)
+        feature_dict[f"sm_mean{suffix}"] = np.mean(dur)
+        feature_dict[f"sm_std{suffix}"] = np.std(dur, ddof=1)
+        feature_dict[f"sm_skewness{suffix}"] = skew(dur)
 
     if index is None:
         index = 0
@@ -100,7 +101,7 @@ def _get_start_end(
     start: Union[str, pd.Timestamp],
     end: Union[str, pd.Timestamp],
     timezone: str,
-) -> Tuple[Union[str, pd.Timestamp], Union[str, pd.Timestamp]]:
+) -> tuple[Union[str, pd.Timestamp], Union[str, pd.Timestamp]]:
     if timezone is None:
         timezone = tz
 
