@@ -1,12 +1,13 @@
 """A set of util functions to detect static regions in a IMU signal given certain constrains."""
-from typing import Optional, Sequence, Tuple, Union
+
+from collections.abc import Sequence
+from typing import Literal, Optional, Union
 
 import numpy as np
 import pandas as pd
 from numpy.linalg import norm
-from typing_extensions import Literal
 
-from biopsykit.utils._types import arr_t
+from biopsykit.utils._types_internal import arr_t
 from biopsykit.utils.array_handling import (
     _bool_fill,
     bool_array_to_start_end_array,
@@ -30,7 +31,7 @@ def _find_static_samples(
     window_length: int,
     inactive_signal_th: float,
     metric: METRIC_FUNCTION_NAMES = "mean",
-    overlap: int = None,
+    overlap: Optional[int] = None,
 ) -> np.ndarray:
     """Search for static samples within given input signal, based on windowed L2-norm thresholding.
 
@@ -41,8 +42,8 @@ def _find_static_samples(
 
     Parameters
     ----------
-    data : array with shape (n, 3)
-        3D signal on which static moment detection should be performed (e.g. 3D-acc or 3D-gyr data)
+    data : array with shape (n, 3) or (n, 2)
+        3D or 2D signal on which static moment detection should be performed (e.g. 3D-acc or 3D-gyr data)
     window_length : int
         Length of desired window in units of samples
     inactive_signal_th : float
@@ -80,11 +81,11 @@ def _find_static_samples(
 
     """
     # test for correct input data shape
-    if np.shape(data)[-1] != 3:
-        raise ValueError("Invalid signal dimensions, signal must be of shape (n,3).")
+    if np.shape(data)[-1] != 3 and np.shape(data)[-1] != 2:
+        raise ValueError("Invalid signal dimensions, signal must be of shape (n,3) or (n, 2).")
 
     if metric not in _METRIC_FUNCTIONS:
-        raise ValueError("Invalid metric passed! {} as metric is not supported.".format(metric))
+        raise ValueError(f"Invalid metric passed! {metric} as metric is not supported.")
 
     # add default overlap value
     if overlap is None:
@@ -116,7 +117,7 @@ def _find_static_sequences(
     window_length: int,
     inactive_signal_th: float,
     metric: METRIC_FUNCTION_NAMES = "variance",
-    overlap: int = None,
+    overlap: Optional[int] = None,
 ) -> np.ndarray:
     """Search for static sequences within given input signal, based on windowed L2-norm thresholding.
 
@@ -126,8 +127,8 @@ def _find_static_sequences(
 
     Parameters
     ----------
-    data : array with shape (n, 3)
-        3D signal on which static moment detection should be performed (e.g. 3D-acc or 3D-gyr data)
+    data : array with shape (n, 3) or (n, 2)
+        3D or 2D signal on which static moment detection should be performed (e.g. 3D-acc or 3D-gyr data)
     window_length : int
         Length of desired window in units of samples
     inactive_signal_th : float
@@ -184,8 +185,8 @@ def find_static_moments(
 
     Parameters
     ----------
-    data : array with shape (n, 3)
-        3D signal on which static moment detection should be performed (e.g. 3D-acc or 3D-gyr data)
+    data : array with shape (n, 3) or (n, 2)
+        3D or 2D signal on which static moment detection should be performed (e.g. 3D-acc or 3D-gyr data)
     window_samples : int, optional
         window size in samples or ``None`` if window size is specified in seconds + sampling rate. Default: ``None``
     window_sec : int, optional
@@ -253,7 +254,7 @@ def find_first_static_window_multi_sensor(
     window_length: int,
     inactive_signal_th: float,
     metric: METRIC_FUNCTION_NAMES,
-) -> Tuple[int, int]:
+) -> tuple[int, int]:
     """Find the first time window in the signal where all provided sensors are static.
 
     Parameters
@@ -281,7 +282,7 @@ def find_first_static_window_multi_sensor(
 
     """
     if metric not in _METRIC_FUNCTIONS:
-        raise ValueError("`metric` must be one of {}".format(list(_METRIC_FUNCTIONS.keys())))
+        raise ValueError(f"`metric` must be one of {list(_METRIC_FUNCTIONS.keys())}")
 
     if not isinstance(signals, np.ndarray):
         # all signals should have the same shape
@@ -293,12 +294,11 @@ def find_first_static_window_multi_sensor(
                 "the sensor axis."
             )
         signals = np.hstack(signals)
-    else:
-        if signals.ndim != 3:
-            raise ValueError(
-                "If a array is used as input, it must be 3D, where the first dimension is the time, "
-                "the second indicates the sensor and the third the axis of the sensor."
-            )
+    elif signals.ndim != 3:
+        raise ValueError(
+            "If a array is used as input, it must be 3D, where the first dimension is the time, "
+            "the second indicates the sensor and the third the axis of the sensor."
+        )
 
     n_signals = signals.shape[1]
 
