@@ -1,12 +1,13 @@
 """Module for detection non-wear times from raw acceleration signals."""
+
 import datetime
-from typing import Tuple, Union
+from typing import Union
 
 import numpy as np
 import pandas as pd
 
 from biopsykit.utils._datatype_validation_helper import _assert_has_columns
-from biopsykit.utils._types import arr_t
+from biopsykit.utils._types_internal import arr_t
 from biopsykit.utils.array_handling import sliding_window
 
 
@@ -15,6 +16,20 @@ class WearDetection:
 
     Non-wear times are estimated over 15 minute intervals over the day.
 
+    The non-wear detection was implemented according to [1] and modified according to [2].
+
+
+    References
+    ----------
+    [1] Van Hees, V. T., Renström, F., Wright, A., Gradmark, A., Catt, M., Chen, K. Y., Löf, M., Bluck, L.,
+    Pomeroy, J., Wareham, N. J., Ekelund, U., Brage, S., & Franks, P. W. (2011). Estimation of Daily Energy
+    Expenditure in Pregnant and Non-Pregnant Women Using a Wrist-Worn Tri-Axial Accelerometer. PLoS ONE, 6(7), e22922.
+    https://doi.org/10.1371/journal.pone.0022922
+
+    [2] van Hees, V. T., Gorzelniak, L., Taherian, S., & Ekelund, U. (2013). Separating Movement and Gravity Components
+    in an Acceleration Signal and Implications for the Assessment of Human Daily Physical Activity. PLOS ONE, 8(4), 10.
+    https://doi.org/doi.org/10.1371/journal.pone.0061691
+
     """
 
     sampling_rate: float
@@ -49,10 +64,7 @@ class WearDetection:
         if isinstance(data, (pd.DataFrame, pd.Series)):
             index = data.index
 
-        if isinstance(data, pd.DataFrame):
-            data = data.filter(like="acc")
-        else:
-            data = pd.DataFrame(data)
+        data = data.filter(like="acc") if isinstance(data, pd.DataFrame) else pd.DataFrame(data)
 
         window = 60  # min
         overlap = 15  # min
@@ -114,10 +126,7 @@ class WearDetection:
         start_end = start_end.astype(int)
 
         if isinstance(index, pd.DatetimeIndex):
-            index_resample = pd.DataFrame(index.values[start_end], columns=["start", "end"])
-            index_resample = index_resample.apply(
-                lambda df: pd.to_datetime(df).dt.tz_localize("UTC").dt.tz_convert(index.tzinfo)
-            )
+            index_resample = pd.DataFrame(index.to_numpy()[start_end], columns=["start", "end"])
         return index_resample
 
     @staticmethod
@@ -132,19 +141,20 @@ class WearDetection:
                 # get hour lengths of the previous, current, and next blocks
                 dur_prev, dur_curr, dur_post = (len(dur) * 0.25 for dur in [prev, curr, post])
 
-                if dur_curr < 3 and dur_curr / (dur_prev + dur_post) < 0.8:
-                    # if the current block is less than 3 hours and the ratio to previous and post blocks is
+                if (dur_curr < 3 and dur_curr / (dur_prev + dur_post) < 0.8) or (
+                    dur_curr < 6 and dur_curr / (dur_prev + dur_post) < 0.3
+                ):
+                    # a) if the current block is less than 3 hours and the ratio to previous and post blocks is
                     # less than 80% rescore the wear period as non-wear
-                    data.loc[data["block"] == idx_curr, "wear"] = 0
-                elif dur_curr < 6 and dur_curr / (dur_prev + dur_post) < 0.3:
-                    # if the current block is less than 6 hours and the ratio to previous and post blocks is
+                    # b) if the current block is less than 6 hours and the ratio to previous and post blocks is
                     # less than 30% rescore the wear period as non-wear
                     data.loc[data["block"] == idx_curr, "wear"] = 0
-        data.drop(columns=["block"], inplace=True)
+
+        data = data.drop(columns=["block"])
         return data
 
     @staticmethod
-    def get_major_wear_block(data: pd.DataFrame) -> Tuple[Union[datetime.datetime, int], Union[datetime.datetime, int]]:
+    def get_major_wear_block(data: pd.DataFrame) -> tuple[Union[datetime.datetime, int], Union[datetime.datetime, int]]:
         """Return major wear block.
 
         The major wear block is the longest continuous wear block in the data.
@@ -178,7 +188,7 @@ class WearDetection:
 
     @staticmethod
     def cut_to_wear_block(
-        data: pd.DataFrame, wear_block: Tuple[Union[datetime.datetime, int], Union[datetime.datetime, int]]
+        data: pd.DataFrame, wear_block: tuple[Union[datetime.datetime, int], Union[datetime.datetime, int]]
     ) -> pd.DataFrame:
         """Cut data to wear block.
 
