@@ -1,5 +1,7 @@
 """Module for processing Respiration data."""
-from typing import Dict, Optional, Sequence, Union
+
+from collections.abc import Sequence
+from typing import Optional, Union
 
 import neurokit2 as nk
 import numpy as np
@@ -17,9 +19,9 @@ class RspProcessor(_BaseProcessor):
 
     def __init__(
         self,
-        data: Union[pd.DataFrame, Dict[str, pd.DataFrame]],
+        data: Union[pd.DataFrame, dict[str, pd.DataFrame]],
         sampling_rate: Optional[float] = None,
-        time_intervals: Optional[Union[pd.Series, Dict[str, Sequence[str]]]] = None,
+        time_intervals: Optional[Union[pd.Series, dict[str, Sequence[str]]]] = None,
         include_start: Optional[bool] = False,
     ):
         """Initialize an ``RspProcessor`` instance.
@@ -72,7 +74,7 @@ class RspProcessor(_BaseProcessor):
         References
         ----------
         Schäfer, A., & Kratky, K. W. (2008). Estimation of Breathing Rate from Respiratory Sinus Arrhythmia:
-        Comparison of Various Methods. *Annals of Biomedical Engineering*, 36(3), 476–485.
+        Comparison of Various Methods. *Annals of Biomedical Engineering*, 36(3), 476-485.
         https://doi.org/10.1007/s10439-007-9428-1
 
 
