@@ -1,4 +1,5 @@
 """Module for analysis of sleep-related data, e.g. polysomnography or IMU/actigraphy data collected during sleep."""
+
 from biopsykit.sleep import plotting, psg, sleep_endpoints, sleep_processing_pipeline, sleep_wake_detection, utils
 
-__all__ = ["utils", "sleep_endpoints", "plotting", "psg", "sleep_wake_detection", "sleep_processing_pipeline"]
+__all__ = ["plotting", "psg", "sleep_endpoints", "sleep_processing_pipeline", "sleep_wake_detection", "utils"]
