@@ -1,11 +1,13 @@
 """Functions for computing sleep endpoints, i.e., parameters that characterize a recording during a sleep study."""
+
+from collections.abc import Sequence
 from numbers import Number
-from typing import Optional, Sequence, Union
+from typing import Optional, Union
 
 import numpy as np
 import pandas as pd
 
-from biopsykit.utils.datatype_helper import SleepEndpointDataFrame, SleepEndpointDict, _SleepEndpointDataFrame
+from biopsykit.utils.dtypes import SleepEndpointDataFrame, SleepEndpointDict, _SleepEndpointDataFrame
 
 
 def compute_sleep_endpoints(
@@ -48,7 +50,7 @@ def compute_sleep_endpoints(
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SleepEndpointDict`
+    :obj:`~biopsykit.utils.dtypes.SleepEndpointDict`
         dictionary with computed sleep endpoints
 
     """
@@ -67,14 +69,14 @@ def compute_sleep_endpoints(
     # get percent of total time asleep
     sleep_efficiency = 100.0 * (len(net_sleep_time) / len(sleep_wake))
     # wake after sleep onset = duration of wake during first and last 'sleep' sample
-    wake_after_sleep_onset = len(df_sw_sleep) - int(df_sw_sleep.sum()[0])
+    wake_after_sleep_onset = len(df_sw_sleep) - int(df_sw_sleep.sum().iloc[0])
 
     df_sw_sleep["block"] = df_sw_sleep["sleep_wake"].diff().ne(0).cumsum()
-    df_sw_sleep.reset_index(inplace=True)
-    df_sw_sleep.rename(columns={"index": "time"}, inplace=True)
+    df_sw_sleep = df_sw_sleep.reset_index()
+    df_sw_sleep = df_sw_sleep.rename(columns={"index": "time"})
     bouts = df_sw_sleep.groupby(by="block")
     df_start_stop = bouts.first()
-    df_start_stop.rename(columns={"time": "start"}, inplace=True)
+    df_start_stop = df_start_stop.rename(columns={"time": "start"})
     df_start_stop["end"] = bouts.last()["time"]
 
     # add 1 min to end for continuous time coverage
@@ -134,12 +136,12 @@ def endpoints_as_df(sleep_endpoints: SleepEndpointDict) -> Optional[SleepEndpoin
 
     Parameters
     ----------
-    sleep_endpoints : :obj:`~biopsykit.utils.datatype_helper.SleepEndpointDict`
+    sleep_endpoints : :obj:`~biopsykit.utils.dtypes.SleepEndpointDict`
         dictionary with computed Sleep Endpoints
 
     Returns
     -------
-    :obj:`~biopsykit.utils.datatype_helper.SleepEndpointDataFrame`
+    :obj:`~biopsykit.utils.dtypes.SleepEndpointDataFrame`
         dataframe with computed Sleep Endpoints or ``None`` if ``sleep_endpoints`` is ``None``
 
     """
@@ -147,8 +149,8 @@ def endpoints_as_df(sleep_endpoints: SleepEndpointDict) -> Optional[SleepEndpoin
         return None
 
     sleep_endpoints = sleep_endpoints.copy()
-    sleep_bouts = sleep_endpoints.pop("sleep_bouts", None).values.tolist()
-    wake_bouts = sleep_endpoints.pop("wake_bouts", None).values.tolist()
+    sleep_bouts = sleep_endpoints.pop("sleep_bouts", None).to_numpy().tolist()
+    wake_bouts = sleep_endpoints.pop("wake_bouts", None).to_numpy().tolist()
 
     sleep_bouts = [tuple(v) for v in sleep_bouts]
     wake_bouts = [tuple(v) for v in wake_bouts]
@@ -157,9 +159,9 @@ def endpoints_as_df(sleep_endpoints: SleepEndpointDict) -> Optional[SleepEndpoin
     sleep_endpoints.pop("date")
 
     df = pd.DataFrame(sleep_endpoints, index=index)
-    df.fillna(value=np.nan, inplace=True)
+    df = df.fillna(value=np.nan)
     df["sleep_bouts"] = None
     df["wake_bouts"] = None
-    df.at[df.index[0], "sleep_bouts"] = sleep_bouts
-    df.at[df.index[0], "wake_bouts"] = wake_bouts
+    df.at[df.index[0], "sleep_bouts"] = sleep_bouts  # noqa: PD008
+    df.at[df.index[0], "wake_bouts"] = wake_bouts  # noqa: PD008
     return _SleepEndpointDataFrame(df)
