@@ -1,6 +1,7 @@
 """Module for sleep/wake detection base class."""
-from biopsykit.utils._types import arr_t
-from biopsykit.utils.datatype_helper import SleepWakeDataFrame
+
+from biopsykit.utils._types_internal import arr_t
+from biopsykit.utils.dtypes import SleepWakeDataFrame
 
 
 class _SleepWakeBase:
