@@ -1,12 +1,13 @@
 """Sleep/Wake detection using the *Cole/Kripke Algorithm*."""
+
 import numpy as np
 import pandas as pd
 
 from biopsykit.sleep.sleep_wake_detection.algorithms._base import _SleepWakeBase
 from biopsykit.sleep.sleep_wake_detection.utils import rescore
-from biopsykit.utils._types import arr_t
+from biopsykit.utils._types_internal import arr_t
 from biopsykit.utils.array_handling import sanitize_input_1d
-from biopsykit.utils.datatype_helper import SleepWakeDataFrame, _SleepWakeDataFrame
+from biopsykit.utils.dtypes import SleepWakeDataFrame, _SleepWakeDataFrame
 
 
 class ColeKripke(_SleepWakeBase):
@@ -33,12 +34,12 @@ class ColeKripke(_SleepWakeBase):
         References
         ----------
         Cole, R. J., Kripke, D. F., Gruen, W., Mullaney, D. J., & Gillin, J. C. (1992). Automatic Sleep/Wake
-        Identification From Wrist Activity. *Sleep*, 15(5), 461–469. https://doi.org/10.1093/sleep/15.5.461
+        Identification From Wrist Activity. *Sleep*, 15(5), 461-469. https://doi.org/10.1093/sleep/15.5.461
 
         """
         super().__init__(**kwargs)
 
-    def fit(self, data: arr_t, **kwargs):
+    def fit(self, data: arr_t, **kwargs):  # noqa: ARG002
         """Fit sleep/wake detection algorithm to input data.
 
         .. note::
@@ -72,7 +73,7 @@ class ColeKripke(_SleepWakeBase):
 
         Returns
         -------
-        :obj:`~biopsykit.utils.datatype_helper.SleepWakeDataFrame`
+        :obj:`~biopsykit.utils.dtypes.SleepWakeDataFrame`
             dataframe with sleep/wake predictions
 
         """
