@@ -1,13 +1,14 @@
 """Sleep/Wake detection using the *Sazonov Algorithm*."""
+
 import numpy as np
 import pandas as pd
 from scipy.special import expit
 
 from biopsykit.sleep.sleep_wake_detection.algorithms._base import _SleepWakeBase
 from biopsykit.sleep.sleep_wake_detection.utils import rescore
-from biopsykit.utils._types import arr_t
+from biopsykit.utils._types_internal import arr_t
 from biopsykit.utils.array_handling import sanitize_input_1d, sliding_window
-from biopsykit.utils.datatype_helper import SleepWakeDataFrame, _SleepWakeDataFrame
+from biopsykit.utils.dtypes import SleepWakeDataFrame, _SleepWakeDataFrame
 
 
 class Sazonov(_SleepWakeBase):
@@ -27,7 +28,7 @@ class Sazonov(_SleepWakeBase):
         """
         super().__init__(**kwargs)
 
-    def fit(self, data: arr_t, **kwargs):
+    def fit(self, data: arr_t, **kwargs):  # noqa: ARG002
         """Fit sleep/wake detection algorithm to input data.
 
         .. note::
@@ -61,7 +62,7 @@ class Sazonov(_SleepWakeBase):
 
         Returns
         -------
-        :obj:`~biopsykit.utils.datatype_helper.SleepWakeDataFrame`
+        :obj:`~biopsykit.utils.dtypes.SleepWakeDataFrame`
             dataframe with sleep/wake predictions
 
         """
