@@ -1,15 +1,16 @@
 """Module for setting up a pipeline for statistical analysis."""
+
 import re
 import warnings
+from collections.abc import Sequence
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Literal, Optional, Union
 
 import pandas as pd
 import pingouin as pg
-from typing_extensions import Literal
 
 from biopsykit.utils._datatype_validation_helper import _assert_file_extension, _assert_has_index_levels
-from biopsykit.utils._types import path_t, str_t
+from biopsykit.utils._types_internal import path_t, str_t
 
 MAP_STAT_TESTS = {
     "normality": pg.normality,
@@ -104,7 +105,7 @@ _eff_cols = ["np2", "ng2", "n2", "hedges", "cohen", "CLES"]
 class StatsPipeline:
     """Class to set up a pipeline for statistical analysis."""
 
-    def __init__(self, steps: Sequence[Tuple[str, str]], params: Dict[str, str], **kwargs):
+    def __init__(self, steps: Sequence[tuple[str, str]], params: dict[str, str], **kwargs):
         """Class to set up a pipeline for statistical analysis.
 
         The purpose of such a pipeline is to assemble several steps of a typical statistical analysis procedure while
@@ -190,14 +191,14 @@ class StatsPipeline:
         self.steps = steps
         self.params = params
         self.data: Optional[pd.DataFrame] = None
-        self.results: Dict[str, pd.DataFrame] = {}
+        self.results: dict[str, pd.DataFrame] = {}
         self.category_steps = {}
-        self.round = kwargs.get("round", {col: 4 for col in _sig_cols})
+        self.round = kwargs.get("round", dict.fromkeys(_sig_cols, 4))
         for step in self.steps:
             self.category_steps.setdefault(step[0], [])
             self.category_steps[step[0]].append(step[1])
 
-    def apply(self, data: pd.DataFrame) -> Dict[str, pd.DataFrame]:
+    def apply(self, data: pd.DataFrame) -> dict[str, pd.DataFrame]:
         """Apply statistical analysis pipeline on input data.
 
         Parameters
@@ -234,7 +235,7 @@ class StatsPipeline:
             test_func = MAP_STAT_TESTS[step[1]]
             if len(grouper) > 0:
                 result = data.groupby(grouper, sort=general_params.get("sort", True)).apply(
-                    lambda df: test_func(data=df, **specific_params, **params)  # pylint:disable=cell-var-from-loop
+                    lambda df, tf=test_func, sp=specific_params, p=params: tf(data=df, **sp, **p)
                 )
             else:
                 result = test_func(data=data, **specific_params, **params)
@@ -253,7 +254,7 @@ class StatsPipeline:
         return pipeline_results
 
     @staticmethod
-    def _get_grouper_variable(general_params: Dict[str, str], specific_params: Dict[str, str]):
+    def _get_grouper_variable(general_params: dict[str, str], specific_params: dict[str, str]):
         grouper_tmp = []
         if "groupby" in specific_params:
             grouper_tmp = specific_params.pop("groupby")
@@ -266,7 +267,7 @@ class StatsPipeline:
         return grouper_tmp
 
     @staticmethod
-    def _get_specific_params_prep(grouper: List[str], general_params: Dict[str, str], specific_params: Dict[str, str]):
+    def _get_specific_params_prep(grouper: list[str], general_params: dict[str, str], specific_params: dict[str, str]):
         if "within" in general_params and "between" in general_params:
             grouper.append(general_params["within"])
             specific_params["group"] = general_params["between"]
@@ -275,7 +276,7 @@ class StatsPipeline:
 
         return grouper, specific_params
 
-    def results_cat(self, category: STATS_CATEGORY) -> Union[pd.DataFrame, Dict[str, pd.DataFrame]]:
+    def results_cat(self, category: STATS_CATEGORY) -> Union[pd.DataFrame, dict[str, pd.DataFrame]]:
         """Return results for pipeline category.
 
         This function filters results from steps belonging to the specified category and returns them.
@@ -311,7 +312,7 @@ class StatsPipeline:
         display(self._param_df().T)
         display(self._result_df().T)
 
-    def display_results(self, sig_only: Optional[Union[str, bool, Sequence[str], Dict[str, bool]]] = None, **kwargs):
+    def display_results(self, sig_only: Optional[Union[str, bool, Sequence[str], dict[str, bool]]] = None, **kwargs):
         """Display formatted results of statistical analysis pipeline.
 
         This function displays the results of the statistical analysis pipeline. The output is Markdown-formatted and
@@ -367,22 +368,19 @@ class StatsPipeline:
         else:
             self._display_results(sig_only, **kwargs)
 
-    def _get_sig_only(self, sig_only: Optional[Union[str, bool, Sequence[str], Dict[str, bool]]] = None):
+    def _get_sig_only(self, sig_only: Optional[Union[str, bool, Sequence[str], dict[str, bool]]] = None):
         if sig_only is None:
             sig_only = {}
         if isinstance(sig_only, str):
-            if sig_only == "all":
-                sig_only = True
-            else:
-                sig_only = [sig_only]
+            sig_only = True if sig_only == "all" else [sig_only]
         if isinstance(sig_only, bool):
-            sig_only = {cat: sig_only for cat in self.category_steps}
+            sig_only = dict.fromkeys(self.category_steps, sig_only)
         if isinstance(sig_only, list):
             sig_only = {cat: cat in sig_only for cat in self.category_steps}
         return sig_only
 
     def _display_results(
-        self, sig_only: Dict[str, bool], groupby: Optional[str] = None, group_key: Optional[str] = None, **kwargs
+        self, sig_only: dict[str, bool], groupby: Optional[str] = None, group_key: Optional[str] = None, **kwargs
     ):
         try:
             from IPython.core.display import Markdown, display  # pylint:disable=import-outside-toplevel
@@ -443,7 +441,19 @@ class StatsPipeline:
             raise ValueError(f"No results for category {stats_category}!")
         if "Contrast" in results.columns:
             if stats_effect_type == "interaction":
-                key = f"{self.params['within']} * {self.params['between']}"
+                if "between" in self.params and "within" in self.params:
+                    # interaction
+                    effect1 = self.params["within"]
+                    effect2 = self.params["between"]
+                elif "between" in self.params:
+                    # two-level between
+                    effect1 = self.params["between"][0]
+                    effect2 = self.params["between"][1]
+                else:
+                    # two-level within
+                    effect1 = self.params["within"][0]
+                    effect2 = self.params["within"][1]
+                key = f"{effect1} * {effect2}"
             else:
                 key = self.params[stats_effect_type]
 
@@ -485,12 +495,12 @@ class StatsPipeline:
         stats_effect_type: STATS_EFFECT_TYPE,
         stats_type: Optional[STATS_EFFECT_TYPE] = None,
         plot_type: Optional[PLOT_TYPE] = "single",
-        features: Optional[Union[str, Sequence[str], Dict[str, Union[str, Sequence[str]]]]] = None,
+        features: Optional[Union[str, Sequence[str], dict[str, Union[str, Sequence[str]]]]] = None,
         x: Optional[str] = None,
         subplots: Optional[bool] = False,
     ) -> Union[
-        Tuple[Sequence[Tuple[str, str]], Sequence[float]],
-        Tuple[Dict[str, Sequence[Tuple[Tuple[str, str], Tuple[str, str]]]], Dict[str, Sequence[float]]],
+        tuple[Sequence[tuple[str, str]], Sequence[float]],
+        tuple[dict[str, Sequence[tuple[tuple[str, str], tuple[str, str]]]], dict[str, Sequence[float]]],
     ]:
         """Generate *significance brackets* used indicate statistical significance in boxplots.
 
@@ -566,8 +576,8 @@ class StatsPipeline:
     def _sig_brackets_dict(
         box_pairs: pd.Series,
         pvalues: pd.Series,
-        features: Union[Sequence, Dict[str, Union[str, Sequence[str]]]],
-    ) -> Tuple[Dict[str, Sequence[Tuple[Tuple[str, str], Tuple[str, str]]]], Dict[str, Sequence[float]]]:
+        features: Union[Sequence, dict[str, Union[str, Sequence[str]]]],
+    ) -> tuple[dict[str, Sequence[tuple[tuple[str, str], tuple[str, str]]]], dict[str, Sequence[float]]]:
         dict_box_pairs = {}
         dict_pvalues = {}
         if features is None:
@@ -605,7 +615,7 @@ class StatsPipeline:
     def stats_to_latex(
         self,
         stats_test: Optional[str] = None,
-        index: Optional[Union[Tuple, str]] = None,
+        index: Optional[Union[tuple, str]] = None,
         data: Optional[pd.Series] = None,
     ) -> str:
         """Generate LaTeX output from statistical results.
@@ -693,8 +703,8 @@ class StatsPipeline:
         unstack_levels: Optional[str_t] = None,
         collapse_dof: Optional[bool] = True,
         si_table_format: Optional[str] = None,
-        index_kws: Optional[Dict[str, Any]] = None,
-        column_kws: Optional[Dict[str, Any]] = None,
+        index_kws: Optional[dict[str, Any]] = None,
+        column_kws: Optional[dict[str, Any]] = None,
         show_a_b: Optional[bool] = False,
         **kwargs,
     ) -> str:
@@ -817,7 +827,7 @@ class StatsPipeline:
         if len(data.index.names) > 1:
             data.index = data.index.droplevel(-1)
         data = data.assign(**{pcol: data.loc[:, pcol].apply(self._format_pvals_stars)})
-        data = data.applymap(self._format_number)
+        data = data.map(self._format_number)
 
         if unstack_levels is not None:
             data = data.stack()
@@ -892,10 +902,7 @@ class StatsPipeline:
         if levels is None:
             levels = []
         elif isinstance(levels, bool):
-            if levels:
-                levels = list(data.index.names)[:-1]
-            else:
-                levels = []
+            levels = list(data.index.names)[:-1] if levels else []
         elif isinstance(levels, str):
             levels = [levels]
         return levels
@@ -918,14 +925,14 @@ class StatsPipeline:
             else:
                 stats_data = stats_category_or_data
         else:
-            raise ValueError(
+            raise TypeError(
                 "Either string with stats category (e.g., 'test' or 'posthoc') or dataframe with stats results must "
                 "be supplied as parameter! "
             )
         return self._filter_sig(stats_data)
 
     @staticmethod
-    def _sanitize_features_input(features: Union[str, Sequence[str], Dict[str, Union[str, Sequence[str]]]]):
+    def _sanitize_features_input(features: Union[str, Sequence[str], dict[str, Union[str, Sequence[str]]]]):
         if isinstance(features, str):
             features = [features]
         if isinstance(features, dict):
@@ -940,7 +947,7 @@ class StatsPipeline:
         self,
         stats_data: pd.DataFrame,
         plot_type: Optional[PLOT_TYPE] = "single",
-        features: Optional[Union[Sequence[str], Dict[str, Union[str, Sequence[str]]]]] = None,
+        features: Optional[Union[Sequence[str], dict[str, Union[str, Sequence[str]]]]] = None,
         x: Optional[str] = None,
     ):
         if features is not None:
@@ -949,6 +956,8 @@ class StatsPipeline:
                 features = list(features.values())
                 features = [item for sublist in features for item in sublist]
             if all(isinstance(feature, str) for feature in features):
+                if isinstance(features, str):
+                    features = [features]
                 stats_data = pd.concat(stats_data.filter(like=f, axis=0) for f in features)
             else:
                 stats_data = stats_data.unstack().loc[features].stack()
@@ -964,9 +973,12 @@ class StatsPipeline:
 
     def _get_stats_data_box_pairs_interaction(self, stats_data: pd.DataFrame):
         stats_data = stats_data.reset_index()
-        stats_data = stats_data[stats_data[self.params["within"]] != "-"]
+
+        within_param = self.params["within"][0] if not isinstance(self.params["within"], str) else self.params["within"]
+
+        stats_data = stats_data[stats_data[within_param] != "-"]
         index = stats_data[self.params.get("groupby", [])]
-        stats_data = stats_data.set_index(self.params["within"])
+        stats_data = stats_data.set_index(within_param)
 
         box_pairs = stats_data.apply(lambda row: ((row.name, row["A"]), (row.name, row["B"])), axis=1)
         if not index.empty:
@@ -996,7 +1008,7 @@ class StatsPipeline:
         return stats_data.apply(lambda row: ((row.name, row["A"]), (row.name, row["B"])), axis=1)
 
     def _display_category(  # pylint:disable=too-many-branches
-        self, category: str, steps: Sequence[str], sig_only: Dict[str, bool], groupby: str, group_key: str
+        self, category: str, steps: Sequence[str], sig_only: dict[str, bool], groupby: str, group_key: str
     ):
         try:
             from IPython.core.display import Markdown, display  # pylint:disable=import-outside-toplevel
@@ -1059,11 +1071,8 @@ class StatsPipeline:
         data = data.rename(columns=rename_dict)
         columns = []
         if collapse_dof:
-            if "df1" in data.columns:
-                dof_cols = ["df1", "df2"]
-            else:
-                dof_cols = ["df"]
-            dofs = tuple((data[col].unique() for col in dof_cols))
+            dof_cols = ["df1", "df2"] if "df1" in data.columns else ["df"]
+            dofs = tuple(data[col].unique() for col in dof_cols)
             if any(len(d) != 1 for d in dofs):
                 raise ValueError(f"Cannot collapse dof in table: dof are not unique! Got {dofs}.")
             dofs = [self._format_dof(dof[0]) for dof in dofs]
@@ -1077,7 +1086,7 @@ class StatsPipeline:
                 data = data.drop(columns=["df1", "df2"])
             columns.append("df")
         eff_name = self._get_effsize_name(data)
-        columns = columns + [pcol, eff_name]
+        columns = [*columns, pcol, eff_name]
         data = data[columns]
         return data
 
@@ -1086,11 +1095,8 @@ class StatsPipeline:
         data = data.rename(columns=rename_dict)
         columns = []
         if collapse_dof:
-            if "df2" in data.columns:
-                dof_cols = ["df1", "df2"]
-            else:
-                dof_cols = ["df1"]
-            dofs = tuple((data[col].unique() for col in dof_cols))
+            dof_cols = ["df1", "df2"] if "df2" in data.columns else ["df1"]
+            dofs = tuple(data[col].unique() for col in dof_cols)
             if any(len(d) != 1 for d in dofs):
                 raise ValueError(f"Cannot collapse dof in table: dof are not unique! Got {dofs}.")
             dofs = [self._format_dof(dof[0]) for dof in dofs]
@@ -1109,7 +1115,7 @@ class StatsPipeline:
                 data["df"] = "{" + data["df1"].astype(str) + ", " + data["df2"].astype(str) + "}"
                 data = data.drop(columns=["df1", "df2"])
             columns.append("df")
-        columns = columns + [pcol]
+        columns = [*columns, pcol]
         data = data[columns]
         return data
 
@@ -1139,13 +1145,13 @@ class StatsPipeline:
 
     @staticmethod
     def _format_latex_table_index(
-        data: pd.DataFrame, index_kws: Dict[str, Any], show_a_b: Optional[bool] = False
+        data: pd.DataFrame, index_kws: dict[str, Any], show_a_b: Optional[bool] = False
     ):  # pylint:disable=too-many-branches
         index_italic = index_kws.get("index_italic", True)
-        index_level_order = index_kws.get("index_level_order", None)
-        index_value_order = index_kws.get("index_value_order", None)
-        index_rename_map = index_kws.get("index_rename_map", None)
-        index_level_names_tex = index_kws.get("index_level_names_tex", None)
+        index_level_order = index_kws.get("index_level_order")
+        index_value_order = index_kws.get("index_value_order")
+        index_rename_map = index_kws.get("index_rename_map")
+        index_level_names_tex = index_kws.get("index_level_names_tex")
 
         if isinstance(data.columns, pd.MultiIndex):
             data.columns.names = [None for _ in data.columns.names]
@@ -1175,11 +1181,11 @@ class StatsPipeline:
         return data
 
     @staticmethod
-    def _format_latex_table_column(data: pd.DataFrame, column_kws: Dict[str, Any]):  # pylint:disable=too-many-branches
-        column_level_order = column_kws.get("column_level_order", None)
-        column_value_order = column_kws.get("column_value_order", None)
-        column_rename_map = column_kws.get("column_rename_map", None)
-        column_level_names_tex = column_kws.get("column_level_names_tex", None)
+    def _format_latex_table_column(data: pd.DataFrame, column_kws: dict[str, Any]):  # pylint:disable=too-many-branches
+        column_level_order = column_kws.get("column_level_order")
+        column_value_order = column_kws.get("column_value_order")
+        column_rename_map = column_kws.get("column_rename_map")
+        column_level_names_tex = column_kws.get("column_level_names_tex")
 
         if column_level_order is not None:
             data = data.reorder_levels(column_level_order, axis=1)
@@ -1199,42 +1205,40 @@ class StatsPipeline:
 
     @staticmethod
     def _apply_index_value_order(
-        data: pd.DataFrame, index_value_order: Union[Sequence[str], Dict[str, Sequence[str]]]
+        data: pd.DataFrame, index_value_order: Union[Sequence[str], dict[str, Sequence[str]]]
     ) -> pd.DataFrame:
         if isinstance(data.index, pd.MultiIndex):
             if isinstance(index_value_order, dict):
                 for key, val in index_value_order.items():
                     data = data.reindex(val, level=key)
             else:
-                raise ValueError(
+                raise TypeError(
                     "'index_value_order' must be a dictionary with index level names as keys and "
                     "index values as values."
                 )
+        elif isinstance(index_value_order, dict):
+            data = data.reindex(index_value_order[data.index.name])
         else:
-            if isinstance(index_value_order, dict):
-                data = data.reindex(index_value_order[data.index.name])
-            else:
-                data = data.reindex(index_value_order)
+            data = data.reindex(index_value_order)
         return data
 
     @staticmethod
     def _apply_column_value_order(
-        data: pd.DataFrame, column_value_order: Union[Sequence[str], Dict[str, Sequence[str]]]
+        data: pd.DataFrame, column_value_order: Union[Sequence[str], dict[str, Sequence[str]]]
     ) -> pd.DataFrame:
         if isinstance(data.columns, pd.MultiIndex):
             if isinstance(column_value_order, dict):
                 for key, val in column_value_order.items():
                     data = data.reindex(val, level=key, axis=1)
             else:
-                raise ValueError(
+                raise TypeError(
                     "'column_value_order' must be a dictionary with column level names as keys and "
                     "column values as values."
                 )
+        elif isinstance(column_value_order, dict):
+            data = data.reindex(column_value_order[data.index.name], axis=1)
         else:
-            if isinstance(column_value_order, dict):
-                data = data.reindex(column_value_order[data.index.name], axis=1)
-            else:
-                data = data.reindex(column_value_order, axis=1)
+            data = data.reindex(column_value_order, axis=1)
         return data
 
     @staticmethod
