@@ -1,9 +1,10 @@
 """Module containing various utility functions (time, dataframe, array, file handling, ...)."""
+
 from biopsykit.utils import (
     array_handling,
     data_processing,
     dataframe_handling,
-    datatype_helper,
+    dtypes,
     exceptions,
     file_handling,
     functions,
@@ -12,13 +13,13 @@ from biopsykit.utils import (
 )
 
 __all__ = [
-    "time",
-    "functions",
-    "file_handling",
-    "datatype_helper",
     "array_handling",
-    "dataframe_handling",
-    "exceptions",
     "data_processing",
+    "dataframe_handling",
+    "dtypes",
+    "exceptions",
+    "file_handling",
+    "functions",
     "legacy_helper",
+    "time",
 ]
