@@ -1,11 +1,13 @@
 """Internal helpers for dataset validation."""
+
+from collections.abc import Iterable, Sequence
 from pathlib import Path
-from typing import Any, Iterable, List, Optional, Sequence, Tuple, Union
+from typing import Any, Optional, Union
 
 import numpy as np
 import pandas as pd
 
-from biopsykit.utils._types import _Hashable, path_t
+from biopsykit.utils._types_internal import _Hashable, path_t
 from biopsykit.utils.exceptions import FileExtensionError, ValidationError, ValueRangeError
 
 
@@ -33,7 +35,7 @@ def _assert_is_dir(path: path_t, raise_exception: Optional[bool] = True) -> Opti
     file_name = Path(path)
     if not file_name.is_dir():
         if raise_exception:
-            raise ValueError("The path '{}' is expected to be a directory, but it's not!".format(path))
+            raise ValueError(f"The path '{path}' is expected to be a directory, but it's not!")
         return False
 
     return True
@@ -72,15 +74,15 @@ def _assert_file_extension(
     if file_name.suffix not in expected_extension:
         if raise_exception:
             raise FileExtensionError(
-                "The file name extension is expected to be one of {}. "
-                "Instead it has the following extension: {}".format(expected_extension, file_name.suffix)
+                f"The file name extension is expected to be one of {expected_extension}. "
+                f"Instead it has the following extension: {file_name.suffix}"
             )
         return False
     return True
 
 
 def _assert_is_dtype(
-    obj, dtype: Union[type, Tuple[type, ...]], raise_exception: Optional[bool] = True
+    obj, dtype: Union[type, tuple[type, ...]], raise_exception: Optional[bool] = True
 ) -> Optional[bool]:
     """Check if an object has a specific data type.
 
@@ -105,9 +107,7 @@ def _assert_is_dtype(
     """
     if not isinstance(obj, dtype):
         if raise_exception:
-            raise ValidationError(
-                "The data object is expected to be one of ({},). But it is a {}".format(dtype, type(obj))
-            )
+            raise ValidationError(f"The data object is expected to be one of ({dtype},). But it is a {type(obj)}")
         return False
     return True
 
@@ -200,7 +200,7 @@ def _assert_has_index_levels(
 
 def _assert_has_columns(
     df: pd.DataFrame,
-    columns_sets: Sequence[Union[List[_Hashable], List[str], pd.Index]],
+    column_sets: Sequence[Union[list[_Hashable], list[str], pd.Index]],
     raise_exception: Optional[bool] = True,
 ) -> Optional[bool]:
     """Check if the dataframe has at least all columns sets.
@@ -209,7 +209,7 @@ def _assert_has_columns(
     ----------
     df : :class:`~pandas.DataFrame`
         The dataframe to check
-    columns_sets : list
+    column_sets : list
         Column set or list of column sets to check
     raise_exception : bool, optional
         whether to raise an exception or return a bool value
@@ -233,19 +233,18 @@ def _assert_has_columns(
     """
     columns = df.columns
     result = False
-    for col_set in columns_sets:
+    for col_set in column_sets:
         result = result or all(v in columns for v in col_set)
 
     if result is False:
-        if len(columns_sets) == 1:
-            helper_str = "the following columns: {}".format(columns_sets[0])
+        if len(column_sets) == 1:
+            helper_str = f"the following columns: {column_sets[0]}"
         else:
-            helper_str = "one of the following sets of columns: {}".format(columns_sets)
+            helper_str = f"one of the following sets of columns: {column_sets}"
         if raise_exception:
             raise ValidationError(
-                "The dataframe is expected to have {}. Instead it has the following columns: {}".format(
-                    helper_str, list(df.columns)
-                )
+                f"The dataframe is expected to have {helper_str}. "
+                f"Instead it has the following columns: {list(df.columns)}"
             )
     return result
 
@@ -295,7 +294,7 @@ def _assert_has_column_multiindex(
 
 def _assert_has_columns_any_level(
     df: pd.DataFrame,
-    columns_sets: Sequence[Union[List[_Hashable], List[str], pd.Index]],
+    columns_sets: Sequence[Union[list[_Hashable], list[str], pd.Index]],
     raise_exception: Optional[bool] = True,
 ) -> Optional[bool]:
     """Check if the dataframe has the expected set of column names at any level of a :any:`pandas.MultiIndex`.
@@ -336,13 +335,13 @@ def _assert_has_columns_any_level(
 
     if result is False:
         if len(columns_sets) == 1:
-            helper_str = "the following columns: {}".format(columns_sets[0])
+            helper_str = f"the following columns: {columns_sets[0]}"
         else:
-            helper_str = "one of the following sets of columns: {}".format(columns_sets)
+            helper_str = f"one of the following sets of columns: {columns_sets}"
         if raise_exception:
             raise ValidationError(
-                "The dataframe is expected to have {} at any level of the MultiIndex. Instead it has the "
-                "following MultiIndex columns: {}".format(helper_str, column_levels)
+                f"The dataframe is expected to have {helper_str} at any level of the MultiIndex. Instead it has the "
+                f"following MultiIndex columns: {column_levels}"
             )
     return result
 
@@ -423,10 +422,10 @@ def _assert_value_range(
         if raise_exception:
             raise ValueRangeError(
                 "Some of the values are out of the expected range. "
-                "Expected were values in the range {}, got values in the range {}. "
+                f"Expected were values in the range {value_range}, got values in the range {[min_val, max_val]}. "
                 "If values are part of questionnaire scores, "
                 "you can convert questionnaire items into the correct range by calling "
-                "`biopsykit.questionnaire.utils.convert_scale()`.".format(value_range, [min_val, max_val])
+                "`biopsykit.questionnaire.utils.convert_scale()`."
             )
         return False
     return True
@@ -463,7 +462,7 @@ def _assert_num_columns(
         if raise_exception:
             raise ValidationError(
                 "The dataframe does not have the required number of columns. "
-                "Expected were any of {} columns, but has {} columns.".format(num_cols, len(data.columns))
+                f"Expected were any of {num_cols} columns, but has {len(data.columns)} columns."
             )
         return False
     return True
@@ -496,7 +495,7 @@ def _assert_len_list(data: Sequence, length: int, raise_exception: Optional[bool
         if raise_exception:
             raise ValidationError(
                 "The list does not have the required length. "
-                "Expected was length {}, but it has length {}.".format(length, len(data))
+                f"Expected was length {length}, but it has length {len(data)}."
             )
         return False
     return True
@@ -525,13 +524,22 @@ def _assert_dataframes_same_length(
         if ``raise_exception`` is ``True`` and ``data`` does not have the required length
 
     """
-    if len(set(len(df) for df in df_list)) != 1:
+    if len({len(df) for df in df_list}) != 1:
         if raise_exception:
             raise ValidationError("Not all dataframes have the same length!")
         return False
     return True
 
 
+def _assert_sample_columns_int(data: pd.DataFrame) -> None:
+    """Assert that the columns of a DataFrame that have "_sample" in their name are of type int."""
+    if not any(data.columns.str.contains("_sample")):
+        raise ValidationError("DataFrame does not contain any columns with '_sample' in their name!")
+    for col in data.columns:
+        if "_sample" in col and not pd.api.types.is_integer_dtype(data[col]):
+            raise ValidationError(f"Column '{col}' is not of type 'int'!")
+
+
 def _multiindex_level_names_helper_get_expected_levels(
     ac_levels: Sequence[str],
     ex_levels: Sequence[str],
@@ -544,11 +552,10 @@ def _multiindex_level_names_helper_get_expected_levels(
             expected = ex_levels == ac_levels_slice
         else:
             expected = ex_levels == ac_levels
+    elif match_atleast:
+        expected = all(level in ac_levels for level in ex_levels)
     else:
-        if match_atleast:
-            expected = all(level in ac_levels for level in ex_levels)
-        else:
-            expected = sorted(ex_levels) == sorted(ac_levels)
+        expected = sorted(ex_levels) == sorted(ac_levels)
 
     return expected
 
@@ -561,23 +568,19 @@ def _multiindex_level_names_helper(
     match_order: Optional[bool] = False,
     raise_exception: Optional[bool] = True,
 ) -> Optional[bool]:
-
     if isinstance(level_names, str):
         level_names = [level_names]
 
     ex_levels = list(level_names)
-    if idx_or_col == "index":
-        ac_levels = list(df.index.names)
-    else:
-        ac_levels = list(df.columns.names)
+    ac_levels = list(df.index.names) if idx_or_col == "index" else list(df.columns.names)
 
     expected = _multiindex_level_names_helper_get_expected_levels(ac_levels, ex_levels, match_atleast, match_order)
 
     if not expected:
         if raise_exception:
             raise ValidationError(
-                "The dataframe is expected to have exactly the following {} level names {}, "
-                "but it has {}".format(idx_or_col, level_names, ac_levels)
+                f"The dataframe is expected to have exactly the following {idx_or_col} level names {level_names}, "
+                f"but it has {ac_levels}"
             )
         return False
     return True
@@ -591,28 +594,24 @@ def _multiindex_check_helper(
     nlevels_atleast: Optional[int] = False,
     raise_exception: Optional[bool] = True,
 ) -> Optional[bool]:
-
     has_multiindex, nlevels_act = _multiindex_check_helper_get_levels(df, idx_or_col)
 
     if has_multiindex is not expected:
         return _multiindex_check_helper_not_expected(idx_or_col, nlevels, nlevels_act, expected, raise_exception)
 
     if has_multiindex is True:
-        if nlevels_atleast:
-            expected = nlevels_act >= nlevels
-        else:
-            expected = nlevels_act == nlevels
+        expected = nlevels_act >= nlevels if nlevels_atleast else nlevels_act == nlevels
         if not expected:
             if raise_exception:
                 raise ValidationError(
-                    "The dataframe is expected to have a MultiIndex with {0} {1} levels. "
-                    "But it has a MultiIndex with {2} {1} levels.".format(nlevels, idx_or_col, nlevels_act)
+                    f"The dataframe is expected to have a MultiIndex with {nlevels} {idx_or_col} levels. "
+                    f"But it has a MultiIndex with {nlevels_act} {idx_or_col} levels."
                 )
             return False
     return True
 
 
-def _multiindex_check_helper_get_levels(df: pd.DataFrame, idx_or_col: str) -> Tuple[bool, int]:
+def _multiindex_check_helper_get_levels(df: pd.DataFrame, idx_or_col: str) -> tuple[bool, int]:
     if idx_or_col == "index":
         has_multiindex = isinstance(df.index, pd.MultiIndex)
         nlevels_act = df.index.nlevels
@@ -629,14 +628,14 @@ def _multiindex_check_helper_not_expected(
     if not expected:
         if raise_exception:
             raise ValidationError(
-                "The dataframe is expected to have a single level as {0}. "
-                "But it has a MultiIndex with {1} {0} levels.".format(idx_or_col, nlevels_act)
+                f"The dataframe is expected to have a single level as {idx_or_col}. "
+                f"But it has a MultiIndex with {nlevels_act} {idx_or_col} levels."
             )
         return False
     if raise_exception:
         raise ValidationError(
-            "The dataframe is expected to have a MultiIndex with {0} {1} levels. "
-            "It has just a single normal {1} level.".format(nlevels, idx_or_col)
+            f"The dataframe is expected to have a MultiIndex with {nlevels} {idx_or_col} levels. "
+            f"It has just a single normal {idx_or_col} level."
         )
     return False
 
@@ -681,12 +680,10 @@ def _check_has_column_prefix_single_col(
 ) -> Optional[bool]:
     if not _assert_is_dtype(col, str, raise_exception=False):
         if raise_exception:
-            raise ValidationError("Column '{}' from {} is not a string!".format(col, columns))
+            raise ValidationError(f"Column '{col}' from {columns} is not a string!")
         return False
     if not col.startswith(prefix):
         if raise_exception:
-            raise ValidationError(
-                "Column '{}' from {} are starting with the required prefix '{}'!".format(col, columns, prefix)
-            )
+            raise ValidationError(f"Column '{col}' from {columns} are starting with the required prefix '{prefix}'!")
         return False
     return True
