@@ -1,17 +1,18 @@
 """Module providing various functions for low-level handling of array data."""
-from typing import List, Optional, Tuple, Union
+
+from typing import Optional, Union
 
 import neurokit2 as nk
 import numpy as np
 import pandas as pd
 from scipy import interpolate, signal
 
-from biopsykit.utils._types import arr_t, str_t
+from biopsykit.utils._datatype_validation_helper import _assert_num_columns
+from biopsykit.utils._types_internal import arr_t, str_t
 
 
 def sanitize_input_1d(data: arr_t) -> np.ndarray:
-    """Convert 1-d array-like data (:class:`~numpy.ndarray`, :class:`~pandas.DataFrame`/:class:`~pandas.Series`) \
-    to a numpy array.
+    """Convert 1-d array-like data (:class:`~pandas.DataFrame`/:class:`~pandas.Series`) to a numpy array.
 
     Parameters
     ----------
@@ -36,10 +37,9 @@ def sanitize_input_1d(data: arr_t) -> np.ndarray:
 
 def sanitize_input_nd(
     data: arr_t,
-    ncols: Optional[Union[int, Tuple[int, ...]]] = None,
+    ncols: Optional[Union[int, tuple[int, ...]]] = None,
 ) -> np.ndarray:
-    """Convert n-d array-like data (:class:`~numpy.ndarray`, :class:`~pandas.DataFrame`/:class:`~pandas.Series`) \
-    to a numpy array.
+    """Convert n-d array-like data (:class:`~pandas.DataFrame`/:class:`~pandas.Series`) to a numpy array.
 
     Parameters
     ----------
@@ -61,22 +61,71 @@ def sanitize_input_nd(
         ncols = [ncols]
 
     if isinstance(data, (pd.Series, pd.DataFrame)):
-        data = data.values
+        data = data.to_numpy()
 
     if ncols is not None:
         if data.ndim == 1:
             if 1 in ncols:
                 return data
-            raise ValueError("Invalid number of columns! Expected one of {}, got 1.".format(ncols))
+            raise ValueError(f"Invalid number of columns! Expected one of {ncols}, got 1.")
         if data.shape[1] not in ncols:
-            raise ValueError("Invalid number of columns! Expected one of {}, got {}.".format(ncols, data.shape[1]))
+            raise ValueError(f"Invalid number of columns! Expected one of {ncols}, got {data.shape[1]}.")
     return data
 
 
+def sanitize_input_series(data: Union[np.ndarray, pd.Series, pd.DataFrame], name: str) -> pd.Series:
+    """Convert input data to a pandas Series.
+
+    Parameters
+    ----------
+    data : array_like
+        input data
+    name : str
+        name of the series
+
+    Returns
+    -------
+    :class:`~pandas.Series`
+        input data as a pandas Series
+
+    """
+    if isinstance(data, pd.Series):
+        return data
+    if isinstance(data, pd.DataFrame):
+        if len(data.columns) > 1:
+            raise ValueError("Dataframe must have only one column to be converted to a Series!")
+        return data.squeeze()
+    return pd.Series(data, name=name)
+
+
+def sanitize_input_dataframe_1d(data: Union[np.ndarray, pd.Series, pd.DataFrame], column: str) -> pd.DataFrame:
+    """Convert input data to a pandas DataFrame with one column.
+
+    Parameters
+    ----------
+    data : array_like
+        input data
+    columns : str
+        name of the column
+
+    Returns
+    -------
+    :class:`~pandas.DataFrame`
+        input data as a pandas DataFrame
+
+    """
+    if isinstance(data, pd.DataFrame):
+        _assert_num_columns(data, 1)
+        return data.rename(columns={data.columns[0]: column})
+    if isinstance(data, pd.Series):
+        return data.to_frame(name=column)
+    return pd.DataFrame(data, columns=[column])
+
+
 def find_extrema_in_radius(
     data: arr_t,
     indices: arr_t,
-    radius: Union[int, Tuple[int, int]],
+    radius: Union[int, tuple[int, int]],
     extrema_type: Optional[str] = "min",
 ) -> np.ndarray:
     """Find extrema values (min or max) within a given radius around array indices.
@@ -122,7 +171,7 @@ def find_extrema_in_radius(
     extrema_funcs = {"min": np.nanargmin, "max": np.nanargmax}
 
     if extrema_type not in extrema_funcs:
-        raise ValueError("`extrema_type` must be one of {}, not {}".format(list(extrema_funcs.keys()), extrema_type))
+        raise ValueError(f"`extrema_type` must be one of {list(extrema_funcs.keys())}, not {extrema_type}")
     extrema_func = extrema_funcs[extrema_type]
 
     # ensure numpy
@@ -150,16 +199,10 @@ def find_extrema_in_radius(
     return extrema_func(windows, axis=1) + indices - lower_limit
 
 
-def _find_extrema_in_radius_get_limits(radius: Union[int, Tuple[int, int]]) -> Tuple[int, int]:
+def _find_extrema_in_radius_get_limits(radius: Union[int, tuple[int, int]]) -> tuple[int, int]:
     # determine upper and lower limit
-    if isinstance(radius, tuple):
-        lower_limit = radius[0]
-    else:
-        lower_limit = radius
-    if isinstance(radius, tuple):
-        upper_limit = radius[-1]
-    else:
-        upper_limit = radius
+    lower_limit = radius[0] if isinstance(radius, tuple) else radius
+    upper_limit = radius[-1] if isinstance(radius, tuple) else radius
 
     # round up and make sure it's an integer
     lower_limit = np.ceil(lower_limit).astype(int)
@@ -219,7 +262,7 @@ def remove_outlier_and_interpolate(
     # remove outlier
     data[outlier_mask] = np.nan
     # fill outlier by linear interpolation of neighbors
-    data = pd.Series(data).interpolate(limit_direction="both").values
+    data = pd.Series(data).interpolate(limit_direction="both").to_numpy()
     # interpolate signal
     x_new = np.linspace(x_old[0], x_old[-1], desired_length)
     return nk.signal_interpolate(x_old, data, x_new, method="linear")
@@ -295,7 +338,7 @@ def sanitize_sliding_window_input(
     sampling_rate: Optional[float] = None,
     overlap_samples: Optional[int] = None,
     overlap_percent: Optional[float] = None,
-) -> Tuple[int, int]:
+) -> tuple[int, int]:
     """Sanitize input parameters for creating sliding windows from array data.
 
     The window size of sliding windows can either be specified in *samples* (``window_samples``)
@@ -543,7 +586,7 @@ def bool_array_to_start_end_array(bool_array: np.ndarray) -> np.ndarray:
     return np.array([[s.start, s.stop] for s in slices])
 
 
-def split_array_equally(data: arr_t, n_splits: int) -> List[Tuple[int, int]]:
+def split_array_equally(data: arr_t, n_splits: int) -> list[tuple[int, int]]:
     """Generate indices to split array into parts with equal lengths.
 
     Parameters
@@ -616,12 +659,11 @@ def add_datetime_index(
     if isinstance(column_name, str):
         # assert list
         column_name = [column_name]
-    if column_name is not None:
-        arr = pd.DataFrame(arr, columns=column_name)
-    else:
-        arr = pd.DataFrame(arr)
+    arr = pd.DataFrame(arr, columns=column_name) if column_name is not None else pd.DataFrame(arr)
+
+    # convert start_time to seconds
+    start_time_s = start_time.timestamp()
 
-    start_time_s = float(start_time.to_datetime64()) / 1e9
     arr.index = pd.to_datetime(
         (arr.index * 1 / sampling_rate + start_time_s).astype(int), utc=True, unit="s"
     ).tz_convert(start_time.tzinfo)
