@@ -1,12 +1,13 @@
 """A set of custom exceptions."""
 
 __all__ = [
-    "ValidationError",
-    "FileExtensionError",
     "DataFrameTransformationError",
-    "ValueRangeError",
-    "FeatureComputationError",
     "EcgProcessingError",
+    "EventExtractionError",
+    "FeatureComputationError",
+    "FileExtensionError",
+    "ValidationError",
+    "ValueRangeError",
 ]
 
 
@@ -32,3 +33,7 @@ class FeatureComputationError(Exception):
 
 class EcgProcessingError(Exception):
     """An error indicating that ECG processing failed."""
+
+
+class EventExtractionError(Exception):
+    """An error indicating that event extraction failed."""
